var __index = {"config":{"lang":["en"],"separator":"[\\s\\-]+","pipeline":["stopWordFilter"]},"docs":[{"location":"index.html","title":"Home","text":""},{"location":"index.html#what-is-2d3d-paint","title":"What is 2D/3D Paint?","text":"<p>2D/3D Paint is a universal tool that enables painting on both 2D and 3D objects. Whether you\u2019re building a modern paint application or adding painting features to your project, this asset offers powerful capabilities with outstanding performance.</p> <p>Getting started is simple: just add a component, and configure a few settings. With 2D/3D Paint, you can paint on various components, including MeshRenderer, SkinnedMeshRenderer, SpriteRenderer, and RawImage.</p> <p>The asset is compatible with all render pipelines. It also works seamlessly with custom shaders, VR environments, and doesn\u2019t require colliders for painting.</p>"},{"location":"index.html#why-is-it-great","title":"Why is it great?","text":"<p>2D/3D Paint stands out as a powerful and versatile tool for several reasons:</p> <ul> <li>Ease of Use: Setting up painting features is straightforward\u2014just add a prefab, attach a component, and tweak a few settings. Even with minimal effort, you can achieve professional results.</li> <li>Broad Compatibility: The asset supports a wide range of Unity versions, rendering pipelines (Standard, URP, HDRP) and input systems: Input Manager and Input System. It\u2019s also compatible with custom shaders and VR, offering flexibility for different project needs.</li> <li>No Colliders Needed: Unlike many other painting tools, 2D/3D Paint doesn\u2019t require colliders to function, simplifying your scene setup and improving performance.</li> <li>High Performance: The asset is optimized to maintain smooth performance even in complex scenes, ensuring that your painting features work seamlessly without causing slowdowns.</li> <li>Customizability: From brushes to shaders, nearly every aspect of the painting experience can be customized, allowing you to tailor the tool to your specific project requirements.</li> <li>Versatility: Whether you\u2019re painting on a 2D sprite or a 3D model, 2D/3D Paint offers robust support for a wide variety of components, making it suitable for games, apps, and creative tools alike.</li> </ul>"},{"location":"index.html#whats-the-best-way-to-update-2d3d-paint-from-an-old-version-to-a-new-one","title":"What\u2019s the best way to update 2D/3D Paint from an old version to a new one?","text":"<p>Before updating, it\u2019s crucial to ensure you have a backup or commit point to roll back to if any issues arise. Once you\u2019re ready, follow these steps:</p> <ul> <li>Backup Your Project: Always start by creating a backup of your project or committing your changes to version control. This safety net will allow you to revert to the previous state if anything goes wrong during the update.</li> <li>Remove the old 2D/3D Paint Folder: Delete the existing 2D/3D Paint folder from your project. This step is important because the Asset Store importer can sometimes lead to script duplication or leave old, unnecessary files behind.</li> <li>Import the new Version: After removing the old folder, import the new version of 2D/3D Paint from the Asset Store. This clean installation ensures that no outdated files remain in your project.</li> </ul>"},{"location":"index.html#does-it-work-everywhere","title":"Does it work everywhere?","text":"<p>Absolutely\u20142D/3D Paint is built to function flawlessly on every platform Unity supports. Whether you\u2019re developing for mobile, desktop, or VR, this asset is optimized to deliver top-notch performance without compromising on features.</p> <p>The asset\u2019s scripts are streamlined and efficient, ensuring that you can paint on 2D and 3D objects with minimal performance overhead. That said, it\u2019s important to remember that 2D/3D Paint works with Unity\u2019s native systems, so performance will still depend on how you use those systems. For instance, high-end effects or complex shaders may naturally be more demanding on mobile devices, regardless of the painting features.</p> <p>What makes 2D/3D Paint so appealing is its flexibility\u2014you can push the boundaries of creativity, whether you\u2019re crafting intricate textures or building an immersive VR painting experience. However, to get the best results, consider your project\u2019s performance budget and make sure your designs align with your platform\u2019s capabilities.</p> <p>In short, 2D/3D Paint not only works everywhere but also empowers you to create wherever your imagination takes you.</p>"},{"location":"api-reference/index.html","title":"API Reference","text":"<p>Welcome to the API Reference section of 2D/3D Paint! This section provides detailed information on the key classes and methods available in the 2D/3D Paint asset.  </p> <p>You\u2019ll find code examples that illustrate how to implement various features and extend the functionality of the asset in your projects. Whether you\u2019re looking for a specific method or seeking a deeper understanding of the API, this guide will serve as your comprehensive resource.</p> <p>Go to Classes and Methods </p> <p>Go to Code Examples </p>"},{"location":"api-reference/api.html","title":"API Reference","text":""},{"location":"api-reference/api.html#inputcontroller","title":"InputController","text":"<p>The <code>InputController</code> class is a singleton component responsible for managing user input.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public int MaxTouchesCount {...}</code> - specifies the maximum number of touches allowed for simultaneous drawing.;</li> <li><code>public InputMethods ActiveInputMethods {...}</code> - defines active input methods: VRMode, Pen, Touch, Mouse. All input methods are enabled by default;</li> <li><code>public IList&lt;Canvas&gt; Canvases {...}</code> - holds a list of canvases that should ignore raycasts, preventing painting on their child objects;</li> <li><code>public bool BlockRaycastsOnPress {...}</code> - determines if painting should be blocked when hovering over canvas items;</li> <li><code>public GameObject[] IgnoreForRaycasts {...}</code> - GameObjects to ignore raycasts (children objects of Canvas that won't prevent painting);</li> <li><code>public Transform PenTransform</code> - Transform of Pen/Hand for painting, used for VR painting;</li> <li><code>public float MinimalDistanceToPaint</code> - minimal distance from Pen to surface to perform painting, used for VR painting;</li> <li><code>public event Action&lt;int, Vector3&gt; OnMouseHover</code> - triggered when the mouse hovers over an object;</li> <li><code>public event Action&lt;int, Vector3, float&gt; OnMouseDown</code> - triggered when a left mouse click occurs on an object;</li> <li><code>public event Action&lt;int, Vector3, float&gt; OnMouseButton</code> - triggered while the left mouse button is held down over an object;</li> <li><code>public event Action&lt;int, Vector3&gt; OnMouseUp</code> - triggered when the left mouse button is released over an object.</li> </ul>"},{"location":"api-reference/api.html#raycastcontroller","title":"RaycastController","text":"<p>The <code>RaycastController</code> class is a singleton responsible for handling ray intersection checks with triangles and storing data about all objects available for raycasting.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public bool UseDepthTexture {...}</code> - determines whether to use a Depth Texture for raycasting, useful when multiple PaintManagers are active in a scene. If using SRP, DepthTexture must be enabled in URP/HDRP settings</li> <li><code>public void InitObject(IPaintManager paintManager, Component paintComponent, Component renderComponent)</code> - initializes PaintManager object;</li> <li><code>public IList&lt;Triangle&gt; GetLineTriangles(IPaintManager paintManager, int fingerId)</code> - returns a list of triangles intersected by a line;</li> <li><code>public Mesh GetMesh(IPaintManager paintManager)</code> - returns the mesh associated with a PaintManager;</li> <li><code>public void DestroyMeshData(IPaintManager paintManager)</code> - destroys the mesh data created for raycasts;</li> <li><code>public void AddCallbackToRequest(IPaintManager sender, int fingerId, Action callback = null)</code> - adds a callback for the PaintManager request;</li> <li><code>public void RequestRaycast(IPaintManager sender, InputData inputData, InputData previousInputData, Action&lt;RaycastRequestContainer&gt; callback = null)</code> - creates a request to find ray-triangle intersections. This is performed in the LateUpdate method;</li> <li><code>public RaycastData TryGetRaycast(RaycastRequestContainer requestContainer, int fingerId, Vector3 pointerPosition)</code> - retrieves raycast data from a previously sent request;</li> <li><code>public RaycastData RaycastLocal(IPaintManager paintManager, Ray ray, Vector3 pointerPosition, int fingerId, bool useWorld = true)</code> - checks if a ray intersects any triangles and returns the corresponding raycast data.</li> </ul>"},{"location":"api-reference/api.html#paintcontroller","title":"PaintController","text":"<p>The <code>PaintController</code> class is a singleton that manages all PaintManagers. It provides shared settings for all PaintManagers when the \u201cUse Shared Settings\u201d flag is enabled; otherwise, each PaintManager uses its own settings.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public bool OverrideCamera { \u2026 }</code> - determines if the camera used for raycasts should be overridden;</li> <li><code>public Camera Camera { \u2026 }</code> - reference to the camera used for raycasting;</li> <li><code>public bool UseSharedSettings</code> - specifies whether shared settings for brush, paint mode, and tool should be used across all PaintManagers;</li> <li><code>public PaintMode PaintMode { \u2026 }</code> - current painting mode;</li> <li><code>public PaintTool Tool { \u2026 }</code> - current tool used for painting;</li> <li><code>public Brush Brush { \u2026 }</code> - returns the brush instance;</li> <li><code>public void RegisterPaintManager(PaintManager paintManager)</code> - registers a PaintManager;</li> <li><code>public void UnRegisterPaintManager(PaintManager paintManager)</code> - unregisters a PaintManager;</li> <li><code>public IPaintMode GetPaintMode(PaintMode mode)</code> - returns an instance of the specified paint mode;</li> <li><code>public PaintManager[] GetActivePaintManagers()</code> - returns an array of active PaintManagers;</li> <li><code>public PaintManager[] GetAllPaintManagers()</code> - returns all registered PaintManagers;</li> <li><code>public IEnumerable&lt;PaintManager&gt; GetAllPaintManagersAsEnumerable()</code> - returns all registered PaintManagers as IEnumerable.</li> </ul>"},{"location":"api-reference/api.html#paintmanager","title":"PaintManager","text":"<p>The <code>PaintManager</code> class is the core component for managing painting operations on objects. It contains instances of the Paint class and the BasePaintObject.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;PaintManager&gt; OnInitialized</code> - triggered when initialization completes; returns the PaintManager instance;</li> <li><code>public event Action OnDisposed</code> - triggered when the PaintManager resources are disposed;</li> <li><code>public GameObject ObjectForPainting { ... }</code> - the GameObject to be painted;</li> <li><code>public Paint Material { ... }</code> - the instance of the Paint class;</li> <li><code>public ILayersController LayersController {...}</code> - reference to LayersController instance;</li> <li><code>public LayersContainer LayersContainer {...}</code> - reference to LayersContainer instance;</li> <li><code>public FilterMode FilterMode { ... }</code> - defines the FilterMode of the RenderTextures;</li> <li><code>public IBrush Brush { ... }</code> - property of the brush used by PaintManager;</li> <li><code>public ToolsManager ToolsManager { ... }</code> - manages all painting tools within the PaintManager;</li> <li><code>public PaintTool Tool { ... }</code> - property of the current painting tool;</li> <li><code>public BasePaintObject PaintObject { \u2026 }</code> - property of the object being painted;</li> <li><code>public IStatesController StatesController { \u2026 }</code> - reference to the StatesController instance;</li> <li><code>public bool CopySourceTextureToLayer {...}</code> - indicates whether the source texture is copied to the layer;</li> <li><code>public bool UseSourceTextureAsBackground { \u2026 }</code> - indicates whether the source texture is used as a background texture;</li> <li><code>public bool HasTrianglesData { \u2026 }</code> - whether the component contains triangle data;</li> <li><code>public Triangles[] Triangles { \u2026 }</code> - get/set triangles array;</li> <li><code>public bool Initialized { \u2026 }</code> - indicates whether the object is initialized;</li> <li><code>public int SubMesh { \u2026 }</code> - defines the submesh of the paint object mesh;</li> <li><code>public int UVChannel { \u2026 }</code> - specifies the UV channel of the mesh;</li> <li><code>public PaintSpace PaintSpace {...}</code> - property of the selected paint space;</li> <li><code>public IPaintMode PaintMode</code> - returns the instance of the current paint mode;</li> <li><code>public void Init()</code> - initializes the PaintManager; if already initialized, it recreates internal data such as RenderTextures, meshes, and materials;</li> <li><code>public void DoDispose()</code> - destroys all resources (e.g., RenderTextures, meshes, materials) and restores the original material and texture;</li> <li><code>public bool IsActive()</code> - returns whether the PaintManager is currently able to perform painting;</li> <li><code>public void Render()</code> - triggers the rendering of the object;</li> <li><code>public void SetPaintMode(PaintMode paintMode)</code> - sets the current paint mode;</li> <li><code>public RenderTexture GetPaintTexture()</code> - returns the combined texture from the painting process;</li> <li><code>public RenderTexture GetPaintInputTexture()</code> - returns the input RenderTexture (current frame\u2019s dot/line or input drawn between mouse events);</li> <li><code>public RenderTexture GetResultRenderTexture()</code> - returns the result RenderTexture (combined layers);</li> <li><code>public Texture2D GetResultTexture(bool hideBrushPreview = false)</code> - returns the final texture (combined layers); hiding the brush preview is optional; ensure proper disposal of the texture to avoid memory leaks;</li> <li><code>public SetLayersData(LayersContainer container)</code> - sets layer data;</li> <li><code>public LayerData[] GetLayersData()</code> - returns the current layer data;</li> <li><code>public bool IsLayersContainerExists(string filename)</code> - checks whether the LayersContainer exists on storage by filename;</li> <li><code>public bool SaveToLayersContainer(string filename)</code> - saves the LayersContainer to storage, returning true on success;</li> <li><code>public bool DeleteLayersContainer(string filename)</code> - deletes the LayersContainer from storage, returning true on success;</li> <li><code>public bool LoadFromLayersContainer(string filename)</code> - loads the LayersContainer from storage, returning true on success;</li> <li><code>public void InitBrush()</code> - initializes the brush settings.</li> </ul>"},{"location":"api-reference/api.html#basepaintobject","title":"BasePaintObject","text":"<p>The <code>BasePaintObject</code> class is the foundation for painting on RenderTexture. Derived classes, such as <code>CanvasRendererPaint</code>, <code>SpriteRendererPaint</code>, <code>MeshRendererPaint</code>, and <code>SkinnedMeshRendererPaintObject</code>, implement logic for checking painting positions based on input data.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;PointerData&gt; OnPointerHover</code> - mouse hover event. Arguments: PointerData that contains paint object local position, screen position, UV position, texture position, pressure, finger id;</li> <li><code>public event Action&lt;PointerData&gt; OnPointerDown</code> - mouse down event. Arguments: PointerData that contains paint object local position, screen position, UV position, texture position, pressure, finger id;</li> <li><code>public event Action&lt;PointerData&gt; OnPointerPress</code>- mouse press event. Arguments: PointerData that contains paint object local position, screen position, UV position, texture position, pressure, finger id;</li> <li><code>public event Action&lt;PointerUpData&gt; OnPointerUp</code> - mouse up event. Arguments: PointerUpData that contains screen position, is mouse in object bounds, finger id;</li> <li><code>public event Action&lt;DrawPointData&gt; OnDrawPoint</code> - draw point event, used by developers to obtain data about painting. Arguments: DrawPointData that contains the texture position, pressure, and finger ID;</li> <li><code>public event Action&lt;DrawLineData&gt; OnDrawLine</code> - draw line event, used by developers to obtain data about painting. Arguments: DrawLineData that contains the start and end texture positions, start and end pressure, and finger ID;</li> <li><code>public bool InBounds { \u2026 }</code> - property indicating whether the user\u2019s object is within bounds for painting;</li> <li><code>public bool IsPainting { \u2026 }</code> - property indicating whether the user is actively painting;</li> <li><code>public bool IsPainted { \u2026 }</code> - property indicating whether painting has occurred in the current frame;</li> <li><code>public bool ProcessInput</code> - property indicating whether input processing is active for the current paint object;</li> <li><code>public void Init(IPaintManager paintManager, IPaintData paintData, Transform objectTransform, Paint paint)</code> - initializes the paint object;</li> <li><code>public void DoDispose()</code> - destroys previously created RenderTextures and meshes;</li> <li><code>public void OnMouseHover(InputData inputData, RaycastData raycastData)</code> - mouse hover method;</li> <li><code>public void OnMouseHoverFailed(InputData inputData)</code> - method invoked when a canvas item blocks the raycast during mouse hover;</li> <li><code>public void OnMouseDown(InputData inputData, RaycastData raycastData)</code> - mouse down method;</li> <li><code>public void OnMouseButton(InputData inputData, RaycastData raycastData)</code> - mouse button press method;</li> <li><code>public void OnMouseFailed(InputData inputData)</code> - method invoked when a canvas item blocks the raycast for mouse down/press events;</li> <li><code>public void OnMouseUp(InputData inputData)</code> - mouse up method;</li> <li><code>public Vector2? GetTexturePosition(InputData inputData, RaycastData raycastData)</code> - returns the paint position from the screen position if the ray intersects with an object;</li> <li><code>public FrameDataBuffer&lt;FrameData&gt; SavePaintState(int fingerId = 0)</code> - saves the paint state for the specified fingerId;</li> <li><code>public void RestorePaintState(FrameDataBuffer&lt;FrameData&gt; paintDataStorage, int fingerId = 0)</code> - restores the paint state for the specified fingerId;</li> <li><code>public void DrawPoint(DrawPointData drawPointData, Action onFinish = null)</code> - draws a point from code using DrawPointData;</li> <li><code>public void DrawPoint(InputData inputData, RaycastData raycastData, Action onFinish = null)</code> - draws a point from code using InputData and RaycastData;</li> <li><code>public void DrawLine(DrawLineData drawLineData, Action onFinish = null)</code> - draw line from code using DrawLineData;</li> <li><code>public void DrawLine(InputData inputDataStart, InputData inputDataEnd, RaycastData raycastDataStart, RaycastData raycastDataEnd, KeyValuePair&lt;Ray, RaycastData&gt;[] raycasts = null, Action onFinish = null)</code> - draw line from code using InputData and RaycastData;</li> <li><code>public void FinishPainting(int fingerId = 0, bool forceFinish = false)</code> - ends painting;</li> <li><code>public void RenderGeometries(bool finishPainting = false)</code> - render to combined RenderTexture;</li> <li><code>public void RenderToTextures()</code> - combines all RenderTextures into the final RenderTexture;</li> <li><code>public void RenderToTextureWithoutPreview(RenderTexture resultTexture)</code> - renders to the final RenderTexture without including the brush preview;</li> <li><code>public void SaveUndoTexture()</code> - saves the active layer texture to the Undo/Redo system;</li> <li><code>public void SetRaycastProcessor(BaseRaycastProcessor processor)</code> - sets the raycast processor.</li> </ul>"},{"location":"api-reference/api.html#statescontroller","title":"StatesController","text":"<p>The <code>StatesController</code> class manages the undo/redo states, handling changes to objects and their previous states.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public int ChangesCount { ... }</code> - the number of changes made;</li> <li><code>public event Action&lt;RenderTexture&gt; OnClearTextureAction</code> - event for clearing the RenderTexture;</li> <li><code>public event Action OnRenderTextureAction</code> - event for undo/redo operations, triggering the object to render;</li> <li><code>public event Action OnChangeState</code> - event for changing the state during undo/redo operations;</li> <li><code>public event Action OnResetState</code> - event to reset the state, typically used to clear the InputTexture;</li> <li><code>public event Action OnUndoRequested</code> - event triggered when an undo action is requested;</li> <li><code>public event Action OnUndo</code> - event triggered when an undo action is performed;</li> <li><code>public event Action OnRedoRequested</code> - event triggered when a redo action is requested;</li> <li><code>public event Action OnRedo</code> - event triggered when a redo action is performed;</li> <li><code>public event Action&lt;bool&gt; OnUndoStatusChanged</code> - event for monitoring changes to the undo status; returns a flag indicating whether an undo can be performed;</li> <li><code>public event Action&lt;bool&gt; OnRedoStatusChanged</code> - event for monitoring changes to the redo status; returns a flag indicating whether a redo can be performed;</li> <li><code>public void DoDispose()</code> - destroys the state data;</li> <li><code>public void Enable()</code> - enables undo/redo functionality;</li> <li><code>public void Disable()</code> - disables undo/redo functionality;</li> <li><code>public void AddState(Action action)</code> - adds a new state by specifying an action;</li> <li><code>public void AddState(object entity, string property, RenderTexture oldValue, RenderTexture newValue, Texture source)</code> - adds a RenderTexture change state;</li> <li><code>public void AddState(object entity, string property, object oldValue, object newValue)</code> - adds a property change state;</li> <li><code>public void AddState(IList collection, NotifyCollectionChangedEventArgs rawEventArg)</code> - adds a state to record changes to a list;</li> <li><code>public void Undo()</code> - performs an undo action;</li> <li><code>public void Redo()</code> - performs a redo action;</li> <li><code>public int GetUndoActionsCount()</code> - returns the number of available undo actions;</li> <li><code>public int GetRedoActionsCount()</code> - returns the number of available redo actions;</li> <li><code>public bool CanUndo()</code> - returns whether an undo action can be performed;</li> <li><code>public bool CanRedo()</code> - returns whether a redo action can be performed;</li> <li><code>public void EnableGrouping(bool useCustomGroup = false)</code> - enables grouping of actions; all actions will be recorded as one group until DisableGrouping() is invoked;</li> <li><code>public void DisableGrouping(bool useCustomGroup = false)</code> - disables action grouping.</li> </ul>"},{"location":"api-reference/api.html#layerscontroller","title":"LayersController","text":"<p>The <code>LayersController</code> class manages layer instances and their properties, allowing the manipulation of layers within a painting context.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;ObservableCollection&lt;ILayer&gt;, NotifyCollectionChangedEventArgs&gt; OnLayersCollectionChanged</code> - event triggered when the layers collection is changed;</li> <li><code>public event Action&lt;ILayer&gt; OnLayerChanged</code> - event triggered when a layer\u2019s render properties change, used to trigger object rendering after layer parameters are modified;</li> <li><code>public event Action&lt;ILayer&gt; OnActiveLayerSwitched</code> - event to change active layer index;</li> <li><code>public event Action&lt;bool&gt; OnCanRemoveLayer</code> - event that returns a flag indicating whether a layer can be removed (at least one layer must remain for painting);</li> <li><code>public ReadOnlyCollection&lt;ILayer&gt; Layers { ... }</code> - collection of all layers;</li> <li><code>public ILayer ActiveLayer { ... }</code> - ithe currently active layer;</li> <li><code>public bool CanDisableLayer { ... }</code> - property indicating whether the active layer can be disabled (prevents disabling all layers);</li> <li><code>public bool CanRemoveLayer { ... }</code> - property indicating whether the active layer can be removed (prevents removing the last layer);</li> <li><code>public bool CanMergeLayers { ... }</code> - property indicating whether the active layer can be merged with the layer below it (both layers must be enabled);</li> <li><code>public bool CanMergeAllLayers { ... }</code> - property indicating whether all enabled layers can be merged (at least two layers must be enabled);</li> <li><code>public int ActiveLayerIndex { ... }</code> - index of the active layer;</li> <li><code>public void DoDispose()</code> - releases all layer data;</li> <li><code>public void Init(int width, int height)</code> - initializes the layers with the specified width and height;</li> <li><code>public void CreateBaseLayers(Texture sourceTexture, bool copySourceTextureToLayer, bool useSourceTextureAsBackground)</code> - creates default layers using the source texture;</li> <li><code>public void SetFilterMode(FilterMode mode)</code> - sets the filter mode for layer textures;</li> <li><code>public ILayer AddNewLayer()</code> - creates and adds a new layer;</li> <li><code>public ILayer AddNewLayer(string name)</code> - creates and adds a new layer with the specified name;</li> <li><code>public ILayer AddNewLayer(string name, Texture sourceTexture)</code> - creates and adds a new layer with the specified name and source texture;</li> <li><code>public void AddLayerMask(ILayer layer, Texture source)</code> - adds a layer mask using the specified source texture;</li> <li><code>public void AddLayerMask(ILayer layer)</code> - adds a layer mask to the specified layer;</li> <li><code>public void AddLayerMask(Texture source)</code> - adds a layer mask to the active layer using the source texture;</li> <li><code>public void AddLayerMask()</code> - adds a layer mask to the active layer;</li> <li><code>public void RemoveActiveLayerMask()</code> - removes the mask from the active layer;</li> <li><code>public ILayer GetActiveLayer()</code> - returns the active layer;</li> <li><code>public void SetActiveLayer(ILayer layer)</code> - sets the specified layer as active;</li> <li><code>public void SetActiveLayer(int index)</code> - sets the active layer by index;</li> <li><code>public void SetLayerOrder(ILayer layer, int index)</code> - sets the order of the specified layer;</li> <li><code>public void RemoveActiveLayer()</code> - removes the active layer;</li> <li><code>public void RemoveLayer(ILayer layer)</code> - removes the specified layer;</li> <li><code>public void RemoveLayer(int index)</code> - removes the layer by index;</li> <li><code>public void MergeLayers()</code> - merges the active layer with the layer below it (both must be enabled);</li> <li><code>public void MergeAllLayers()</code> - merges all enabled layers into the active layer (at least two layers must be enabled);</li> <li><code>public void SetLayerTexture(int index, Texture texture)</code> - sets the texture for the specified layer index;</li> <li><code>public Texture2D GetActiveLayerTexture()</code> - returns the texture of the active layer (Texture2D). Note that it should be destroyed properly to avoid memory leaks;</li> <li><code>public Texture2D GetLayerTexture(int layerIndex)</code> - returns the texture (Texture2D) of the layer at the specified index. Like GetActiveLayerTexture(), the texture should be disposed of properly.</li> </ul>"},{"location":"api-reference/api.html#layer","title":"Layer","text":"<p>The <code>Layer</code> class represents an individual layer, managing its data and properties.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;ILayer&gt; OnLayerChanged</code> - event triggered when layer properties are changed;</li> <li><code>public Action&lt;Layer&gt; OnRenderPropertyChanged</code> - event triggered when rendering properties that affect the layer are changed;</li> <li><code>public bool Enabled { ... }</code> - property indicating whether the layer is enabled;</li> <li><code>public bool CanBeDisabled { ... }</code> - property indicating whether the layer can be disabled;</li> <li><code>public bool MaskEnabled { ... }</code> - property indicating whether the mask is enabled for the layer;</li> <li><code>public string Name { ... }</code> - name of the layer;</li> <li><code>public float Opacity { ... }</code> - opacity of the layer;</li> <li><code>public Texture SourceTexture { ... }</code> - the source texture of the layer;</li> <li><code>public RenderTexture RenderTexture { ... }</code> - the render texture for the layer;</li> <li><code>public RenderTargetIdentifier RenderTarget { ... }</code> - identifier for the render texture;</li> <li><code>public Texture MaskSourceTexture { ... }</code> - the source texture for the mask;</li> <li><code>public RenderTexture MaskRenderTexture { ... }</code> - the render texture for the mask;</li> <li><code>public RenderTargetIdentifier MaskRenderTarget { ... }</code> - identifier for the mask render texture;</li> <li><code>public BlendingMode BlendingMode { ... }</code> - the blending mode of the layer;</li> <li><code>public void Create(string layerName, int width, int height, RenderTextureFormat format, FilterMode filterMode)</code> - creates a render texture for the layer with the specified parameters;</li> <li><code>public void Create(string layerName, Texture source, RenderTextureFormat format, FilterMode filterMode)</code> - creates a render texture for the layer using the specified source texture;</li> <li><code>public void Init(CommandBufferBuilder bufferBuilder, Func&lt;bool&gt; canDisableLayer)</code> - initializes the layer;</li> <li><code>public void AddMask(RenderTextureFormat format)</code> - creates a mask for the layer with the specified render texture format;</li> <li><code>public void AddMask(Texture maskTexture, RenderTextureFormat format)</code> - creates a mask for the layer using the specified texture and format;</li> <li><code>public void RemoveMask()</code> - removes the mask from the layer;</li> <li><code>public void SaveState()</code> - saves the state of the layer\u2019s render texture using the StatesController;</li> <li><code>public void DoDispose()</code> - releases all layer data.</li> </ul>"},{"location":"api-reference/api.html#paint","title":"Paint","text":"<p>The <code>Paint</code> class stores and manages painting material data and its parameters.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public Material PaintMaterial { \u2026 }</code> - the material used for painting;</li> <li><code>public Material PaintWorldMaterial { \u2026 }</code> - material used for painting in PaintSpace.World;</li> <li><code>public string ShaderTextureName { \u2026 }</code> - the name of the shader texture used for painting;</li> <li><code>public int DefaultTextureWidth { \u2026 }</code> - width of the texture if the object doesn\u2019t have a source texture;</li> <li><code>public int DefaultTextureHeight { \u2026 }</code> - height of the texture if the object doesn\u2019t have a source texture;</li> <li><code>public Color DefaultTextureColor { \u2026 }</code> - default color for the texture;</li> <li><code>public ProjectionMethod ProjectionMethod { \u2026 }</code> - determines the method used to project the brush texture onto the surface. Usage:<ul> <li><code>Planar Projection</code>: Projects the brush texture onto the surface along a single plane defined by the brush normal. Ideal for flat or slightly curved surfaces;</li> <li><code>Triplanar Projection</code>: Blends the brush texture across three orthogonal planes (X, Y, Z axes). Useful when the surface orientation varies significantly.</li> </ul> </li> <li><code>public ProjectionDirection ProjectionDirection { \u2026 }</code> - determines how the brush normal is calculated for texture projection. Usage:<ul> <li><code>Normal</code>: uses the triangle normal direction;</li> <li><code>Ray</code>: uses the raycast direction.</li> </ul> </li> <li><code>public float NormalCutout { \u2026 }</code> - parameter that ensures paint isn\u2019t applied where the surface\u2019s normal angle is too steep compared to the paint ray, helping avoid painting areas that face away from the painting ray in PaintSpace.World. Usage:<ul> <li><code>-1.0</code>: No culling based on normal direction (all surfaces are rendered);</li> <li><code>0.0</code>: Discards surfaces facing away from the viewer;</li> <li><code>1.0</code>: Only surfaces facing exactly towards the viewer are rendered.</li> </ul> </li> <li><code>public float ProjectionMaxAngle { \u2026 }</code> - specifies the maximum angle (in degrees) between the brush normal and the fragment normal for the brush to draw on surface. Adjusting <code>Max Angle</code> allows you to control how much the brush wraps around curved surfaces in PaintSpace.World;</li> <li><code>public AngleAttenuationMode ProjectionAngleAttenuationMode { \u2026 }</code> - controls how <code>Max Angle</code> affects the brush\u2019s alpha value. Usage:<ul> <li><code>Smooth</code> Attenuation for natural, gradual blending on surfaces with varying orientations. Provides gradual transitions on curved surfaces;</li> <li><code>Hard</code> Cutoff for precise control, ensuring the brush effect is only applied within a specific angular range. The brush effect is fully applied to fragments within the angle threshold and completely absent beyond it. </li> </ul> </li> <li><code>public float ProjectionBrushDepth { \u2026 }</code> - controls the depth (thickness) of the brush effect along the brush normal direction, relative to the brush size. Useful for creating effects where the brush should only affect surfaces within a specific depth range in PaintSpace.World. Usage: <ul> <li><code>0.0</code>: Depth attenuation is disabled; the brush affects all fragments within its radius regardless of depth;</li> <li><code>&gt; 0.0</code>: Limits the brush effect to a certain depth, creating a volumetric brush influence.</li> </ul> </li> <li><code>public float ProjectionDepthFadeRange { \u2026 }</code> - defines the range over which the brush effect fades out from full strength to zero along the depth specified by <code>Brush Depth</code>. When greater than 0.0, it creates a smooth transition (fade) from full brush effect to no effect over the specified depth range in PaintSpace.World;</li> <li><code>public float ProjectionEdgeSoftness { \u2026 }</code> - controls the softness of the brush edges, affecting how the brush effect attenuates towards the outer radius in PaintSpace.World. Usage:<ul> <li><code>0.0</code>: Edge attenuation is disabled; the brush has a hard edge;</li> <li><code>&gt; 0.0</code>: Applies an exponential falloff to the brush\u2019s alpha value based on the radial distance from the center, resulting in softer edges.</li> </ul> </li> <li><code>public int MaterialIndex { \u2026 }</code> - index of the material within the object;</li> <li><code>public Texture SourceTexture { \u2026 }</code> - the source texture used by the paint material;</li> <li><code>public void Init(IRenderComponentsHelper renderComponents, Texture source)</code> - initializes the paint material using the render components and source texture;</li> <li><code>public void CreateWorldMaterial()</code> - creates a material for painting in PaintSpace.World;</li> <li><code>public void DoDispose()</code> - destroys previously created materials;</li> <li><code>public void RestoreTexture()</code> - restores the source texture to the material;</li> <li><code>public void SetObjectMaterialTexture(Texture texture)</code> - sets a new texture for the object;</li> <li><code>public void SetPreviewTexture(Texture texture)</code> - sets the texture used for previewing the paint;</li> <li><code>public void SetPaintTexture(Texture texture)</code> - sets the layer texture to the material;</li> <li><code>public void SetInputTexture(Texture texture)</code> - sets the input texture to the material;</li> <li><code>public void SetPreviewVector(Vector4 brushOffset)</code> - sets the vector data to display the brush preview.</li> </ul>"},{"location":"api-reference/api.html#brush","title":"Brush","text":"<p>The <code>Brush</code> class stores and manages the brush material data and its parameters.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;Color&gt; OnColorChanged</code> - event triggered when the brush color changes;</li> <li><code>public event Action&lt;Texture&gt; OnTextureChanged</code> - event triggered when the brush texture changes;</li> <li><code>public event Action&lt;bool&gt; OnPreviewChanged</code> - event triggered when the brush preview flag changes;</li> <li><code>public string Name { \u2026 }</code> - name of the brush, must be unique;</li> <li><code>public Material Material { \u2026 }</code> - material of the brush;</li> <li><code>public FilterMode FilterMode { \u2026 }</code> - filter mode of the brush\u2019s RenderTexture;</li> <li><code>public Color Color { \u2026 }</code> - color of the brush;</li> <li><code>public Texture SourceTexture { \u2026 }</code> - source texture of the brush;</li> <li><code>public RenderTexture RenderTexture { \u2026 }</code> - RenderTexture of the brush;</li> <li><code>public float MinSize { \u2026 }</code> - minimum size of the brush;</li> <li><code>public float Size { \u2026 }</code> - size of the brush;</li> <li><code>public float RenderAngle { \u2026 }</code> - render angle of the brush in degrees;</li> <li><code>public Quaternion RenderQuaternion { \u2026 }</code> - render quaternion of the brush;</li> <li><code>public float Hardness { \u2026 }</code> - hardness of the brush;</li> <li><code>public bool Preview { \u2026 }</code> - flag indicating whether the brush preview is enabled;</li> <li><code>public void Init(IPaintMode mode)</code> - initializes the brush\u2019s material, mesh, and RenderTexture;</li> <li><code>public void DoDispose()</code> - destroys the previously created RenderTexture, mesh, and material;</li> <li><code>public void SetValues(Brush brush)</code> - copies values from another brush;</li> <li><code>public void Render()</code> - renders the brush into the RenderTexture;</li> <li><code>public void RenderFromTexture(Texture texture)</code> - renders the brush from the texture without changing the SourceTexture;</li> <li><code>public void SetColor(Color colorValue, bool render = true, bool sendToEvent = true)</code> - sets the brush color and optionally renders it and sends the event;</li> <li><code>public void SetTexture(Texture texture, bool render = true, bool sendToEvent = true, bool canUpdateRenderTexture = true)</code> - sets the brush texture and optionally renders it, sends the event, and updates the RenderTexture.</li> </ul>"},{"location":"api-reference/api.html#toolsmanager","title":"ToolsManager","text":"<p>The <code>ToolsManager</code> class manages all the tools available for painting within the PaintManager. It handles the registration and selection of painting tools.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;IPaintTool&gt; OnToolChanged</code> - event triggered when the current tool is changed. Arguments: IPaintTool representing the new tool;</li> <li><code>public IPaintTool CurrentTool</code> - returns the current tool;</li> <li><code>public void Init(PaintManager paintManager)</code> - initializes the ToolsManager for the given PaintManager and subscribes to its events;</li> <li><code>public void DoDispose()</code> - releases all tool-related resources;</li> <li><code>public void SetTool(PaintTool paintTool)</code> - sets the specified tool as the active tool;</li> <li><code>public IPaintTool GetTool(PaintTool tool)</code> - retrieves the tool based on the PaintTool type.</li> </ul>"},{"location":"api-reference/api.html#basepainttool","title":"BasePaintTool","text":"<p>The <code>BasePaintTool</code> class is the base class for all painting tools. It processes layer textures using input events from the PaintManager.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public virtual PaintTool Type { \u2026 }</code> - type of the tool;</li> <li><code>protected IPaintData Data</code> - data that the tool has to process an image. Used to get information about layers, RenderTextures, Brush, painting states;</li> <li><code>public virtual bool AllowRender { \u2026 }</code> - indicates whether rendering is allowed;</li> <li><code>public virtual bool CanDrawLines { \u2026 }</code> - indicates whether the tool can draw lines. If false, the user can only draw dots;</li> <li><code>public virtual bool ConsiderPreviousPosition { \u2026 }</code> - determines whether the brush should render if the previous paint position hasn\u2019t changed;</li> <li><code>public virtual bool ShowPreview { \u2026 }</code> - flag indicating whether to show the brush preview;</li> <li><code>public virtual int Smoothing { \u2026 }</code> - smoothing level for line drawing, values range from 1 to 10, where 1 disables smoothing and 10 provides maximum smoothness. Affects SpriteRenderer and RawImage components;</li> <li><code>public virtual bool RandomizePointsQuadsAngle { \u2026 }</code> - indicates whether to randomize angles of quads when drawing points;</li> <li><code>public virtual bool RandomizeLinesQuadsAngle { \u2026 }</code> - indicates whether to randomize angles of quads when drawing lines, useful for simulating spray tool behavior;</li> <li><code>public virtual bool RenderToLayer { \u2026 }</code> - indicates whether to render to the layer texture;</li> <li><code>public virtual bool RenderToInput { \u2026 }</code> - indicates whether to render to the input texture;</li> <li><code>public virtual bool RenderToTextures { \u2026 }</code> - indicates whether to render to any RenderTextures;</li> <li><code>public virtual bool DrawPreProcess { \u2026 }</code> - indicates whether to perform pre-processing before drawing;</li> <li><code>public virtual bool DrawProcess { \u2026 }</code> - indicates whether to perform drawing during the process;</li> <li><code>public virtual bool BakeInputToPaint { \u2026 }</code> - determines whether to bake the input texture to the layer texture;</li> <li><code>public virtual bool ProcessingFinished { \u2026 }</code> - returns whether the tool has finished processing;</li> <li><code>public virtual bool RequiredCombinedTempTexture { \u2026 }</code> - indicates whether the tool requires a temporary combined texture;</li> <li><code>public BasePaintToolSettings BaseSettings { \u2026 }</code> - reference to the base settings of the tool;</li> <li><code>public T Settings { \u2026 }</code> - reference to the specific settings class of the tool;</li> <li><code>public void FillWithColor(Color color)</code> - fills the active layer with the specified color;</li> <li><code>public virtual void OnDrawPreProcess(RenderTargetIdentifier combined)</code> - performs pre-processing before combining layers into the combined texture;</li> <li><code>public virtual void OnDrawProcess(RenderTargetIdentifier combined)</code> - dperforms drawing when combining layers into the combined texture.</li> </ul>"},{"location":"api-reference/api.html#basepainttoolsettings","title":"BasePaintToolSettings","text":"<p>The <code>BasePaintToolSettings</code> class is the base class for settings of all tools. Each tool can have its own derived settings class.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public bool CanPaintLines { \u2026 }</code> - indicates whether the tool can draw lines. If false, the user can only draw dots;</li> <li><code>public bool DrawOnBrushMoveOnly { \u2026 }</code> - determines whether the tool renders the brush only if the previous paint position has changed;</li> <li><code>public int Smoothing { \u2026 }</code> - defines the smoothing level for line drawing, values range from 1 to 10 (where 1 disables smoothing and 10 provides maximum smoothness). In the case of values greater than 1, line painting performs with a 2-frame delay. This parameter affects SpriteRenderer and RawImage components;</li> <li><code>public bool RandomizePointsQuadsAngle { \u2026 }</code> - indicates whether to randomize the angles of quads while drawing points;</li> <li><code>public bool RandomizeLinesQuadsAngle { \u2026 }</code> - indicates whether to randomize the angles of quads while drawing lines. It can be used to simulate spray tool behavior with an appropriate brush texture.</li> </ul> <p>Tools parameters can be displayed in the Inspector tab if they have the [PaintToolSettings] attribute.</p>"},{"location":"api-reference/api.html#averagecolorcalculator","title":"AverageColorCalculator","text":"<p>The <code>AverageColorCalculator</code> component calculates the average color of a texture. It samples the texture based on set accuracy and can exclude transparent pixels if needed.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public event Action&lt;Color&gt; OnGetAverageColor</code> - event triggered when the average color is calculated during painting;</li> <li><code>public PaintManager PaintManager</code> - the PaintManager used to get the average color;</li> <li><code>public PaintRenderTexture PaintRenderTexture</code> - the texture on which the average color is calculated;</li> <li><code>public bool SkipTransparentPixels</code> - flag indicating whether to skip transparent pixels in the source texture during color sampling;</li> <li><code>public void SetAccuracy(int accuracy)</code> - sets the sampling accuracy for color calculation.</li> </ul> <p>The AverageColorCalculator uses the shader XD Paint/Average Color to sample the texture and determine the average color. Two parameters control this process: the main texture and accuracy (which acts as a divider for the number of samples taken). Higher accuracy values increase the number of samples and GPU usage, while lower values improve performance but reduce accuracy.</p>"},{"location":"api-reference/api.html#colliderpainter","title":"ColliderPainter","text":"<p>The <code>ColliderPainter</code> component allows painting on PaintObject surfaces using collision data. It captures raycast positions during OnCollisionEnter and OnCollisionStay events and uses the brush to paint on the object based on the collision data.</p> <p>Key Public Fields, Properties, and Methods:</p> <ul> <li><code>public public event Action&lt;PaintManager&gt;, Collision&gt; OnCollide</code> - event triggered when a collision occurs, allowing painting based on the collision data. The first argument is the PaintManager, and the second is the collision data;</li> <li><code>public public Color Color</code> - color to use for painting during a collision;</li> <li><code>public public float Pressure</code> - value to scale the brush size during painting, simulating pressure sensitivity.</li> </ul>"},{"location":"api-reference/code-examples.html","title":"Code Examples","text":"<p>Below are commonly used methods along with example code snippets for various tasks.</p>"},{"location":"api-reference/code-examples.html#set-brush-size","title":"Set brush size","text":"<pre><code>paintManager.Brush.Size = value;\n</code></pre>"},{"location":"api-reference/code-examples.html#set-brush-hardness","title":"Set brush hardness","text":"<pre><code>paintManager.Brush.Hardness = value;\n</code></pre>"},{"location":"api-reference/code-examples.html#set-brush-color","title":"Set brush color","text":"<pre><code>var brushColor = paintManager.Brush.Color;\nbrushColor = new Color(color.r, color.g, color.b, brushColor.a);\npaintManager.Brush.SetColor(brushColor);\n</code></pre>"},{"location":"api-reference/code-examples.html#set-brush-opacity","title":"Set brush opacity","text":"<pre><code>var color = paintManager.Brush.Color;\ncolor.a = value;\npaintManager.Brush.SetColor(color);\n</code></pre>"},{"location":"api-reference/code-examples.html#set-brush-angle","title":"Set brush angle","text":"<pre><code>paintManager.Brush.RenderAngle = value;\n</code></pre>"},{"location":"api-reference/code-examples.html#creating-paintmanager-from-code","title":"Creating PaintManager from code","text":"<p>PaintManager can be created from code. Here is an example of creating a PaintManager: <pre><code>public void AddPaintManager(GameObject objectForPainting, Material material, string shaderTextureName = \"_MainTex\")\n{\n    var paintManager = objectForPainting.AddComponent&lt;PaintManager&gt;();\n    paintManager.ObjectForPainting = objectForPainting;\n    paintManager.Material.SourceMaterial = material;\n    paintManager.Material.ShaderTextureName = shaderTextureName;\n    paintManager.Init();\n}\n</code></pre></p> <p>To reinitialize a PaintManager with a single line of code, use: <pre><code>paintManager.Init();\n</code></pre></p> <p>Change texture for painting using code <pre><code>public void ChangeTexture(Texture texture)\n{\n    var material = paintManager.Material.SourceMaterial;\n    material.SetTexture(paintManager.Material.ShaderTextureName, texture);\n    paintManager.Material.SourceMaterial = material;\n    paintManager.Init();\n}\n</code></pre></p>"},{"location":"api-reference/code-examples.html#render-repaint-paint-object-and-its-layers","title":"Render (repaint) paint object and its layers","text":"<pre><code>paintManager.Render();\n</code></pre>"},{"location":"api-reference/code-examples.html#set-default-texture-size-for-objects-without-source-texture","title":"Set default texture size for objects without source texture","text":"<pre><code>paintManager.Material.DefaultTextureWidth = \u2026;\npaintManager.Material.DefaultTextureHeight = \u2026;\n</code></pre>"},{"location":"api-reference/code-examples.html#fill-layer-texture-with-a-color","title":"Fill layer texture with a color","text":"<p>This method clears the layer texture: <pre><code>paintManager.Tool = PaintTool.Brush;\npaintManager.ToolsManager.CurrentTool.FillWithColor(Color.clear);\npaintManager.Render();\n</code></pre></p>"},{"location":"api-reference/code-examples.html#change-tool","title":"Change tool","text":"<pre><code>if (PaintController.Instance.UseSharedSettings)\n{\n    // if PaintController has UseSharedSettings enabled\n    PaintController.Instance.Tool = PaintTool...;\n}\nelse\n{\n    // otherwise:\n    paintManager.Tool = PaintTool...;\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#set-blur-tool-parameters","title":"Set blur tool parameters","text":"<pre><code>if (paintManager.ToolsManager.CurrentTool is BlurTool blurTool)\n{\n    blurTool.Settings.Iterations = 3;\n    blurTool.Settings.BlurStrength = 2f;\n    blurTool.Settings.DownscaleRatio = 1;\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#set-gaussian-blur-tool-parameters","title":"Set Gaussian blur tool parameters","text":"<pre><code>if (paintManager.ToolsManager.CurrentTool is GaussianBlurTool gaussianBlurTool)\n{\n    gaussianBlurTool.Settings.KernelSize = 3;\n    gaussianBlurTool.Settings.Spread = 5f;\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#enabledisable-input-for-all-paintmanagers","title":"Enable/Disable input for all PaintManagers","text":"<pre><code>InputController.Instance.enabled = value;\n</code></pre>"},{"location":"api-reference/code-examples.html#enabledisable-input-for-paintmanager-instance","title":"Enable/Disable input for PaintManager instance","text":"<pre><code>paintManager.PaintObject.ProcessInput = value;\n</code></pre>"},{"location":"api-reference/code-examples.html#get-the-average-color-of-a-paintmanager","title":"Get the average color of a PaintManager","text":"<pre><code>public AverageColorCalculator AverageColorCalculator;\n\u2026\nAverageColorCalculator.OnGetAverageColor += color =&gt; Debug.Log(\"Average Color: \" + color);\n</code></pre>"},{"location":"api-reference/code-examples.html#save-painting-result-to-file","title":"Save painting result to file","text":"<pre><code>private void SaveResultToFile(PaintManager paintManager, string path)\n{\n    var texture2D = paintManager.GetResultTexture();\n    var pngData = texture2D.EncodeToPNG();\n    if (pngData != null)\n    {\n        File.WriteAllBytes(path, pngData);\n    }\n    Destroy(texture2D);\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#save-result-texture-to-applicationpersistentdatapath","title":"Save Result Texture to Application.persistentDataPath","text":"<pre><code>private void SaveResultToPersistentDataPath(PaintManager paintManager, string fileName)\n{\n    var texture2D = paintManager.GetResultTexture();\n    var pngData = texture2D.EncodeToPNG();\n    if (pngData != null)\n    {\n        var filePath = System.IO.Path.Combine(Application.persistentDataPath, fileName);\n        System.IO.File.WriteAllBytes(filePath, pngData);\n    }\n    Destroy(texture2D);\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#load-from-texture","title":"Load from texture","text":"<pre><code>public void LoadResultTextureFromFile(PaintManager paintManager, string fileName)\n{\n    var filePath = System.IO.Path.Combine(Application.persistentDataPath, fileName);\n    var textureData = System.IO.File.ReadAllBytes(filePath);\n    var texture = new Texture2D(1, 1);\n    texture.LoadImage(textureData);\n    var shaderTextureName = paintManager.Material.ShaderTextureName;\n    var previousTexture = paintManager.Material.SourceMaterial.GetTexture(shaderTextureName);\n    paintManager.Material.SourceMaterial.SetTexture(shaderTextureName, texture);\n\n    // if using a SpriteRenderer\n    var spriteRenderer = paintManager.ObjectForPainting.GetComponent&lt;SpriteRenderer&gt;();\n    if (spriteRenderer != null)\n    {\n        var sprite = Sprite.Create(texture, new Rect(0, 0, texture.width, texture.height), new Vector2(0.5f, 0.5f));\n        spriteRenderer.sprite = sprite;\n    }\n\n    // if using a RawImage\n    var rawImage = paintManager.ObjectForPainting.GetComponent&lt;RawImage&gt;();\n    if (rawImage != null)\n    {\n        rawImage.texture = texture;\n    }\n\n    // copy texture to new layer:\n    paintManager.CopySourceTextureToLayer = true;\n    // copy texture to background layer:\n    // paintManager.UseSourceTextureAsBackground = true;\n    paintManager.Init();\n    paintManager.Material.SourceMaterial.SetTexture(shaderTextureName, previousTexture);\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#managing-layerscontainer-with-storage","title":"Managing LayersContainer with storage","text":"<pre><code>// save LayersContainer to storage:\nvar filename = \"someFileName\";\nif (paintManager.SaveToLayersContainer(fileName))\n{\n    Debug.Log(\"LayersContainer was successfully saved!\");\n}\n\n// load LayersContainer from storage:\nif (paintManager.LoadFromLayersContainer(fileName))\n{\n    Debug.Log(\"LayersContainer was successfully loaded!\");\n}\n\n// delete LayersContainer from storage:\nvar filename = \"someFileName\";\nif (paintManager.DeleteLayersContainer(fileName))\n{\n    Debug.Log(\"LayersContainer was successfully deleted!\");\n}\n\n// check if LayersContainer exists in storage:\nvar filename = \"someFileName\";\nif (paintManager.IsLayersContainerExists(fileName))\n{\n    Debug.Log(\"LayersContainer exist!\");\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#add-a-new-layer","title":"Add a new layer","text":"<pre><code>var layerName = \"SomeLayerName\";\npaintManager.LayersController.AddNewLayer(layerName);\n</code></pre> <p>To create a layer from an existing texture: <pre><code>var layerName = \"SomeLayerName\";\nvar layerTexture = ... // reference to Texture2D, note that the Texture dimensions must be as the source texture\npaintManager.LayersController.AddNewLayer(layerName, layerTexture);\n</code></pre></p>"},{"location":"api-reference/code-examples.html#remove-layer","title":"Remove layer","text":"<pre><code>var layerIndex = 0;\npaintManager.LayersController.RemoveLayer(layerIndex);\n</code></pre>"},{"location":"api-reference/code-examples.html#drawing-from-code","title":"Drawing from code","text":"<p>To draw in texture space, use the following methods: <pre><code>// draw a point where argument - position on the texture\npaintManager.PaintObject.DrawPoint(new Vector3(512, 512));\n// invoke FinishPainting() when drawing dots are finished. FinishPainting() method also saves the result to undo/redo system\npaintManager.PaintObject.FinishPainting();\n\n\n// draw a line where arguments - start and end position on the texture\npaintManager.PaintObject.DrawLine(new Vector2(400, 612), new Vector2(100, 100));\n// invoke FinishPainting() when drawing lines are finished. FinishPainting() method also saves the result to undo/redo system\npaintManager.PaintObject.FinishPainting();\n</code></pre></p> <p>To draw in UV or World space: <pre><code>InputData prevInputData = default;\nvar screenPos = new Vector3(...); // screen position of painting\nvar ray = Camera.main.ScreenPointToRay(screenPosition); //the ray used for raycasts\nvar inputData = new InputData(ray, screenPosition, 1f, InputSource.Screen, 1);\nRaycastController.Instance.RequestRaycast(PaintManager, inputData, prevInputData, container =&gt;\n{\n    var raycastData = RaycastController.Instance.TryGetRaycast(container, inputData.FingerId, inputData.Ray.origin);\n    // check if we ray intersected an object\n    if (!raycastData.Equals(default))\n    {\n        // then use methods for painting:\n        // PaintManager.PaintObject.OnMouseDown(inputData, raycastData);\n        PaintManager.PaintObject.OnMouseButton(inputData, raycastData);\n        // PaintManager.Render();\n        // PaintManager.PaintObject.OnMouseUp(inputData);\n        // PaintManager.PaintObject.FinishPainting();\n    }\n});\nprevInputData = inputData;\n</code></pre></p>"},{"location":"api-reference/code-examples.html#check-if-user-can-undoredo","title":"Check if user can undo/redo","text":"<pre><code>paintManager.StatesController.CanUndo();\npaintManager.StatesController.CanRedo();\n</code></pre>"},{"location":"api-reference/code-examples.html#subscribe-to-change-state-events","title":"Subscribe to change state events","text":"<pre><code>paintManager.StatesController.OnUndoStatusChanged += OnUndoStatusChanged;\npaintManager.StatesController.OnRedoStatusChanged += OnRedoStatusChanged;\n\nprivate void OnUndoStatusChanged(bool canUndo)\n{\n    Debug.Log(\"Can undo: \" + canUndo);\n}\n\nprivate void OnRedoStatusChanged(bool canRedo)\n{\n    Debug.Log(\"Can redo: \" + canRedo);\n}\n</code></pre>"},{"location":"api-reference/code-examples.html#undoredo-action","title":"Undo/Redo action","text":"<pre><code>paintManager.StatesController.Undo();\npaintManager.StatesController.Redo();\n</code></pre>"},{"location":"api-reference/code-examples.html#remove-undoredo-states","title":"Remove undo/redo states","text":"<pre><code>paintManager.StatesController.ResetStates();\n</code></pre>"},{"location":"assetstore/index.html","title":"Asset Store","text":"<p>Open in Asset Store </p>"},{"location":"changelog/index.html","title":"Changelog","text":""},{"location":"changelog/index.html#v-320","title":"v. 3.2.0","text":"<p><code>New Features:</code></p> <ul> <li>World Space painting: choose between World Space or UV Space for painting;</li> <li>Removed screen-space painting limitation: now painting works seamlessly across all spaces;</li> <li>VR mode enhancements: set a minimum distance between the pen and surface;</li> <li>VR support for SpriteRenderer and RawImage: paint directly on these components in VR mode.</li> </ul> <p><code>Other:</code></p> <ul> <li>Removed deprecated methods;</li> <li>Removed BasePaintObject.OnDrawLineExtended event;</li> <li>Removed BasePaintObject.DrawLineExtended method;</li> <li>Documentation rewritten for clarity and convenience;</li> <li>Performance improvements;</li> <li>Bug fixes.</li> </ul>"},{"location":"changelog/index.html#v-313","title":"v. 3.1.3","text":"<p><code>Bug Fixes:</code></p> <ul> <li>Fixed a bug when bucket tool may fill incorrect area.</li> </ul>"},{"location":"changelog/index.html#v-312","title":"v. 3.1.2","text":"<p><code>New Features:</code></p> <ul> <li>Added ability to manage Input methods.</li> </ul> <p><code>Bug Fixes:</code></p> <ul> <li>Fixed a bug when painting may draw extra lines in case when painting was interrupted by clicking on UI;</li> <li>Fixed a bug when DepthToWorldConverter returned incorrect position.</li> </ul>"},{"location":"changelog/index.html#v-311","title":"v. 3.1.1","text":"<p><code>New Features:</code></p> <ul> <li>Added an option to fill only non-transparent pixels in the Bucket tool settings.</li> </ul> <p><code>Bug Fixes:</code></p> <ul> <li>Fixed a bug where undoing after merging layers set an incorrect layer texture;</li> <li>Fixed a bug where input in VR mode threw an exception.</li> </ul>"},{"location":"changelog/index.html#v-310","title":"v. 3.1.0","text":"<p><code>New Features:</code></p> <ul> <li>Added the ability to draw smooth lines for SpriteRenderer and RawImage;</li> <li>Added the ability to save layers container to a file and load from a file;</li> <li>Added the ability to block canvas raycasts with multiple canvases;</li> <li>Introduced the option to randomize brush sample angles while painting.</li> </ul> <p><code>Performance Improvements:</code></p> <ul> <li>Significantly enhanced performance for painting on MeshRenderer/SkinnedMeshRenderer components, especially high-poly models when using the Job System in XDPaintSettings;</li> <li>Improved performance for multi-object painting.</li> </ul> <p><code>Bug Fixes:</code></p> <ul> <li>Fixed a bug where UV data was interpolated, resulting in incorrect positions when drawing lines with MeshRenderer/SkinnedMeshRenderer components;</li> <li>Resolved memory leaks that occurred when users created and removed layers during runtime;</li> <li>Fixed a bug where an exception might be thrown when the PaintManager was created from code with the Undo/Redo system disabled;</li> <li>Fixed a bug where painting on a RawImage didn't work when the Canvas GameObject was inactive at the scene start and the PaintManager was active;</li> <li>Fixed an issue where painting on SkinnedMeshRenderer didn't work when the animator was disabled.</li> </ul> <p><code>Other:</code></p> <ul> <li>Changed PaintManager rendering method from Update() to LateUpdate() to ensure compatibility with JobSystem and Coroutines;</li> <li>BasePaintToolSettings.DrawOnBrushMove was enabled by default;</li> <li>Triangles data/container no longer needed.</li> </ul>"},{"location":"changelog/index.html#v-308","title":"v. 3.0.8","text":"<p><code>Core:</code></p> <ul> <li>New feature: added support for multi-finger allowing users to draw with more than one finger at a time;</li> <li>Fixed a bug when mesh bounds size had an incorrect value;</li> <li>The events PaintManager.PaintObject.OnMouseHoverHandler / OnMouseDownHandler / OnMouseHandler / OnMouseUpHandler / OnDrawPointHandler / OnDrawLineHandler were marked as obsolete and PaintManager.PaintObject.OnPointerHover / OnPointerDown / OnPointerPress / OnPointerUp / OnDrawPoint / OnDrawLine were added instead.</li> </ul>"},{"location":"changelog/index.html#v-307","title":"v. 3.0.7","text":"<ul> <li> <p><code>New Features:</code> </p> </li> <li> <p>New feature: Brush and Bucket tools support painting using pattern texture! You can also control the scale, angle, and offset!</p> </li> <li>New feature: RaycastController can use Depth Texture to prevent paint on the multiple PaintObjects at the same time;</li> <li>Fixed a bug when Undo/Redo system would clear a layer if the order of the layers was changed;</li> <li>Fixed a bug when Undo/Redo system invoked PaintManager.Render() multiple times per action;</li> <li>Fixed a bug when SkinnedMeshRenderer has incorrect boundaries;</li> <li>Fixed a bug where painting on the SkinnedMeshRenderer would not work if the position was changed;</li> <li>Fixed memory leak when a material field didn't have the source texture.</li> </ul> <p><code>Editor:</code></p> <ul> <li>Added PropertyDrawer for ToolManager;</li> <li>Added the ability to manage settings for each PaintManager tool;</li> <li>Tool settings were rewritten from scratch and now can set Texture fields;</li> <li>XDPaintSettings now shows the current version of the asset.</li> </ul> <p><code>Other:</code></p> <ul> <li>The demo scene has been updated, and the user can now invoke the context menu with the right mouse button to manage the settings of the selected tool.</li> </ul>"},{"location":"changelog/index.html#v-306","title":"v. 3.0.6","text":"<p><code>Core:</code></p> <ul> <li>New tool: BUCKET - tool for filling texture parts with selected color;</li> <li>Decreased memory allocations in Runtime;</li> <li>Fixed a bug when the brush preview was not displayed until the first click;</li> <li>Fixed VR Input.</li> </ul>"},{"location":"changelog/index.html#v-305","title":"v. 3.0.5","text":"<p><code>Core:</code></p> <ul> <li>Added ability to paint on a few submeshes of the same paint object simultaneously using a few instances of PaintManager component;</li> <li>Added ability to use Jobs System and Burst Compiler for raycasts to increase performance;</li> <li>Added ability to paint on SpriteRenderer with non-default pivot;</li> <li>Added ability to get layer texture from code;</li> <li>Decreased memory allocations in Runtime;</li> <li>Fixed a bug when the layer Mask was applied incorrectly;</li> <li>Fixed a bug when painting on SkinnedMeshRenderer was performed with offsets when an object has a non-default transform scale;</li> <li>Fixed an exception when Undo/Redo was disabled in XDPaintStatesSettings;</li> <li>Fixed a bug when undo/redo may fill layer texture with solid color;</li> <li>Fixed a bug when SpriteRendererPaint returned an incorrect paint position.</li> </ul> <p>Editor: - Now asset sets Mesh.isReadable = true to Mesh assets automatically.</p>"},{"location":"changelog/index.html#v-304","title":"v. 3.0.4","text":"<p><code>Core:</code></p> <ul> <li>Added new 'Vector3 localPosition' argument to PaintManager.PaintObject.OnMouseHoverHandler / OnMouseDownHandler / OnMouseHandler events to get paint object local position;</li> <li>Fixed a bug when PaintManager.UseSourceTextureAsBackground flag was automatically unchecked if the object didn't have a source texture;</li> <li>Fixed a bug when the layer might have incorrect color when the user invoked Undo in case the object didn't have a source texture;</li> <li>Fixed a bug when CanvasGraphicRaycaster might be removed in case of PaintManager component destroying;</li> <li>Decreased memory allocations in Editor.</li> </ul>"},{"location":"changelog/index.html#v-303","title":"v. 3.0.3","text":"<p><code>Core:</code></p> <ul> <li>Improved drawing using collisions;</li> <li>Added support for Sprite from the atlas.</li> </ul>"},{"location":"changelog/index.html#v-302","title":"v. 3.0.2","text":"<p><code>Core:</code></p> <ul> <li>Added support for pixel art graphics;</li> <li>Improved brush accuracy drawing;</li> <li>Fixed a bug when WebGL build didn't work correctly in case of disabled brush preview;</li> <li>Fixed a bug when some classes were stripped from build;</li> <li>Fixed default texture size for RawImage without source texture;</li> <li>Fixed a bug when layer texture was copied twice in case LayersContainer was used;</li> <li>Fixed a bug when the extra texture was created in case of PaintObject didn't have source texture and LayersContainer was used;</li> <li>Fixed a bug when a brush with a large size has an incorrect preview position.</li> </ul>"},{"location":"changelog/index.html#v-301","title":"v. 3.0.1","text":"<p><code>Core:</code></p> <ul> <li>Fixed a bug when undo/redo could clear the layer texture;</li> <li>Fixed a bug when lines were rendered as dots using old Input Manager on mobile devices;</li> <li>Fixed a bug when the brush was transparent in case of texture size 1x1px.</li> </ul>"},{"location":"changelog/index.html#v-30","title":"v. 3.0","text":"<p><code>Core:</code></p> <ul> <li>New Feature: layers and blending modes. Asset works with layers and supports 26 blending modes;</li> <li>New tool: grayscale - tool for discolorating parts of the texture;</li> <li>Undo/Redo functionality was rewritten from scratch and now supports layers parameters change;</li> <li>Added support for the new Input System and Pen support;</li> <li>Added support for submeshes and UV channels;</li> <li>Added 48 new brushes;</li> <li>Added support for perspective cameras when using the SpriteRenderer component;</li> <li>Added ColliderPainter component to paint with collisions;</li> <li>Added ability to set default texture color;</li> <li>Fixed brush preview offset;</li> <li>Fixed bug when Canvas UI didn't lock input interaction in case of RawImage painting;</li> <li>Optimized memory usage for tools;</li> <li>Improved VR support.</li> </ul> <p><code>Editor:</code></p> <ul> <li>Added CustomEditor for Settings.</li> </ul> <p><code>Other:</code></p> <ul> <li>Updated Manual;</li> <li>API changes (see \"v.3.0_API_Changes.pdf\" for details);</li> <li>Bug fixes.</li> </ul>"},{"location":"features/index.html","title":"Features","text":"<p>\ud83c\udf1f Easy to use No coding skills needed! Simply add a component, tweak a few settings, and you\u2019re ready to go.</p> <p>\ud83d\ude80 Optimized for High Performance Powered by GPU-based painting, ensuring top-notch performance even on mobile devices.</p> <p>\ud83c\udfa8 Compatible with Any Shader Paint using any shader or material of your choice. Just select the textures you want to work with, and you\u2019re all set!</p> <p>\ud83d\udce6 3D Component Support Paint on animated objects effortlessly with MeshRenderer and SkinnedMeshRenderer. Experience smooth performance\u2014check out our WebGL demo to see the magic in action!</p> <p>\ud83c\udfde 2D Component Support Looking to paint in 2D? We\u2019ve got you covered! SpriteRenderer and RawImage are fully supported, making it easy to create your own mobile paint app.</p> <p>\ud83e\udd7d VR Compatibility 2D/3D Paint works seamlessly with any VR device, expanding your creative possibilities.</p> <p>\ud83d\uddbc\ufe0f Layer and Blending Mode Support Paint on multiple layers, merge them, or use blending modes to achieve your desired effects.</p> <p>\ud83e\udd3f Layer Mask Functionality Layers support masks, allowing you to hide parts of a layer with a mask texture for precision painting.</p> <p>\ud83d\udd8c Customizable Brushes Choose from 58 built-in brush presets or add your own custom brushes. Adjust parameters like size, color, hardness, and opacity to suit your needs.</p> <p>\u3030 Smooth Line Drawing Now you can draw smooth lines with SpriteRenderer and RawImage, complete with customizable smoothing parameters for a polished finish.</p> <p>\ud83c\udfc1 Pattern Texture Painting Both Brush and Bucket tools support pattern textures, giving you control over scale, angle, and offset.</p> <p>\ud83d\udd27 Comprehensive Toolset Includes essential tools such as Brush, Erase, Bucket, Eyedropper, Brush Sampler, Clone, Blur, Gaussian Blur, and Grayscale Tool. And guess what? More tools are on the way!</p> <p>\ud83d\udcbb Code-Based Drawing Want to paint programmatically? You can draw on any object directly from code, adding flexibility to your projects.</p> <p>\ud83d\udc7e Pixel Art Precision Enjoy pixel-by-pixel accuracy when working with pixel art graphics.</p> <p>\ud83d\uddb2\ufe0f Input System Integration Works flawlessly with a mouse, touch devices, stylus pens (like Apple Pencil), VR controllers, and more. Multi-finger painting is supported, and both the new Input System and the legacy Input Manager are compatible.</p> <p>\u270f\ufe0f Pressure Sensitivity Use pressure-sensitive devices like the Apple Pencil for nuanced, professional painting results.</p> <p>\ud83d\udc8e No Colliders Needed Our asset features a high-performance raycast system, eliminating the need for colliders.</p> <p>\ud83d\udee0 Render Pipeline Compatibility Supports Standard, Universal Render Pipeline (URP), and High Definition Render Pipeline (HDRP).</p> <p>\ud83d\udd27 Undo/Redo Functionality Made a mistake? No worries\u2014undo and redo your actions, including layer parameter adjustments.</p> <p>\ud83d\udcbe Save and Load Textures/Layers Easily save and load your painted textures and layers, ensuring your work is always preserved.</p> <p>\ud83c\udfa8 Average Color Detection Quickly determine the average color of your painting using our GPU-powered feature for seamless performance.</p> <p>\ud83c\udfaf Collision-Based Drawing Implement drawing using collisions with just a few clicks\u2014it\u2019s that simple!</p> <p>\ud83d\udce0 Long-Term Support Rest assured, you\u2019ll receive ongoing support for future Unity versions and exciting new features. A ton of updates are on the horizon, so stay tuned!</p> <p>\ud83d\udcd6 Full C# Source Code and Example Scene Included Dive deep into the code with full access to the C# source and a comprehensive example scene to get you started.</p>"},{"location":"support/index.html","title":"Support","text":"<p>Please let me know if you have any questions, ideas, or suggestions.</p> <p>If you require support, please provide your invoice number. The more information you provide, the more effectively I can assist you.</p> <p>E-mail: unitymedved@gmail.com Send E-mail </p>"},{"location":"user-guide/index.html","title":"User Guide","text":"<p>Welcome to the 2D/3D Paint User Guide! This section is designed to help you quickly get started and master the essential features of the 2D/3D Paint asset.</p> <p>Here, you\u2019ll find step-by-step instructions for installation, a Quick Start guide to familiarize you with core functionalities, detailed explanations of settings, and in-depth discussions on painting basics. You\u2019ll also learn about the powerful tools and brushes available, how to effectively manage layers, and solutions to common issues in the troubleshooting section. Whether you\u2019re a beginner or an experienced user, this guide has everything you need to harness the full potential of 2D/3D Paint.</p> <p>Need to install or update 2D/3D Paint? Follow the installation guide to get started: Go to Installation </p> <p>Already installed? Jump into the Quick Start guide to begin using the asset: Go to Quick Start </p> <p>Stay informed without an internet connection - download full documentation for offline use: Download Offline Version </p>"},{"location":"user-guide/basics.html","title":"Basics","text":"<p>This section explains how the 2D/3D Paint asset works in Unity, giving you the essential knowledge to start painting on both 2D and 3D objects efficiently.</p>"},{"location":"user-guide/basics.html#core-workflow","title":"Core Workflow","text":"<ol> <li>Material and Texture Handling:<ul> <li>The asset clones the source material and swaps out the original texture for a RenderTexture;</li> <li>This cloned texture is where all the painting happens, enabling high-performance rendering directly on the GPU.</li> </ul> </li> <li>Input Processing:<ul> <li>The asset reads input data (mouse, touch, stylus, or VR controller) and passes it to the RaycastController, which computes the exact position on the object where the painting should occur;</li> <li>Each painting interaction involves calculating two points: where the user last touched (previous frame) and where they are currently touching (current frame). The paint is then applied between these two points.</li> </ul> </li> <li>Layer-Based Painting:<ul> <li>Each layer you paint on is stored as a separate RenderTexture. These layers provide the flexibility to modify or erase strokes without affecting the underlying textures. You can think of layers as transparent canvases stacked on top of one another.</li> </ul> </li> </ol>"},{"location":"user-guide/basics.html#key-components-and-terminology","title":"Key Components and Terminology","text":"<p>To understand how 2D/3D Paint works, it\u2019s important to get familiar with a few key components:</p> <ol> <li>RenderTextures: The core of the painting system. Different textures are created for various purposes:<ul> <li><code>Active Layer Texture</code>: The primary layer where your brush strokes are applied;</li> <li><code>Active Layer Temp Texture</code>: Temporary storage for strokes that will later be baked into the final texture;</li> <li><code>Input Texture</code>: Temporarily stores user input, either for real-time painting (Default Mode) or during the duration of a stroke (Additive Mode);</li> <li><code>Combined Texture</code>: A composite of all active layers, giving you the final visual result;</li> <li><code>Unwrapped Texture</code> (exists in World Paint Space for <code>MeshRenderer</code> and <code>SkinnedMeshRenderer</code> components): A texture that maps the 3D object\u2019s surface for UV-based painting.</li> </ul> </li> <li>Raycasting:<ul> <li>The system determines where on the object the brush should be applied by using raycasting, which calculates intersections between the user\u2019s input and the 3D model;</li> <li>The asset features an optimized raycasting system that bypasses the need for colliders, making the process faster and more efficient;</li> <li>You can further enhance raycast performance with Unity\u2019s Job System for multithreading, especially useful when working with complex models with many vertices.</li> </ul> </li> <li>Brush:<ul> <li>The brush is a RenderTexture that is rendered onto the active layer\u2019s RenderTexture. You can adjust its size, texture, opacity, hardness color and angle. These parameters give you full control over the look of your strokes;</li> <li>Brush size and scale are relative to the layer or object being painted, which ensures consistent results.</li> </ul> </li> </ol>"},{"location":"user-guide/basics.html#paint-modes","title":"Paint Modes","text":"<p>2D/3D Paint offers two distinct painting modes:</p> <ol> <li> <p>Default Mode:</p> <ul> <li>This mode applies paint in real-time, with every stroke being baked into the texture immediately;</li> <li>It\u2019s best suited for rapid and continuous painting tasks where each stroke should instantly affect the final texture.</li> </ul> </li> <li> <p>Additive Mode:</p> <ul> <li>In this mode, paint is applied more gradually, blending colors and opacity with greater accuracy. Each stroke is stored in the Input Texture and only baked into the layer once the user completes the stroke (e.g., on mouse up);</li> <li>Ideal for precise blending and detailed work where smooth transitions between strokes are required.</li> </ul> </li> </ol> Default Paint Mode with 50% opacity Additive Paint Mode with 50% opacity"},{"location":"user-guide/basics.html#paint-spaces","title":"Paint Spaces","text":"<p>2D/3D Paint allows you to work in two main painting spaces:</p> <ol> <li>UV Space:<ul> <li>Painting in UV space applies color to a 2D texture map based on the model\u2019s UV coordinates, ensuring precise control over texture placement.</li> </ul> </li> <li>World Space:<ul> <li>In world space, the brush paints directly on the 3D model using its position in the scene, allowing seamless application across surfaces.</li> </ul> </li> </ol>"},{"location":"user-guide/basics.html#undoredo-system","title":"Undo/Redo System","text":"<p>2D/3D Paint has an undo/redo feature to track and reverse any changes to layers or textures.</p> <ul> <li>Layer Changes: The system stores a record of texture changes after each stroke (e.g., after every OnMouseUp event);</li> <li>Parameter Changes: Adjustments to layer properties such as name, index, and opacity are also stored;</li> <li>Memory Consideration: Note that undoing a texture change can consume a significant amount of memory, especially with larger textures (e.g., a 1024x1024 texture requires 4MB of memory). You can configure this feature in the asset\u2019s settings to limit or disable it.</li> </ul>"},{"location":"user-guide/basics.html#input-support","title":"Input Support","text":"<p>The asset supports a variety of input devices for painting, including:</p> <ul> <li>Mouse;</li> <li>Touch devices (e.g., tablets or phones);</li> <li>Pen/stylus devices (like Apple Pen);</li> <li>VR controllers.</li> </ul> <p>You can switch between Unity\u2019s legacy Input Manager or the newer Input System Package depending on your project needs.</p>"},{"location":"user-guide/best-practices.html","title":"Best Practices","text":"<p>Here are some tips to assist with the configuration and use of 2D/3D Paint.</p>"},{"location":"user-guide/best-practices.html#performance-improvements","title":"Performance improvements","text":"<p>If your app struggle with performance issues, here you can find steps to improve it. Here's steps that may improve the performance:</p> <ol> <li> <p>Brush Duplicate Part: defines the frequency at which brush samples are rendered in case of using <code>SpriteRenderer</code> and <code>RawImage</code> components. This value affects both the number of vertices and the density of the lines. A higher value results in fewer brush samples being drawn, which can reduce the detail and density of the line. Conversely, a lower value will produce more vertices, leading to dense lines. To reduce the number of rendered vertices, set the value to 24, 32 or higher:</p> <p> </p> </li> <li> <p>Raycast Interval: defines the frequency at which raycasts will be performed. A higher value results in fewer brush samples being drawn, which can reduce the detail and density of the line. Conversely, a lower value will produce more vertices, leading to dense lines. To reduce the number of raycasts, increase the value:</p> <p> </p> </li> <li> <p>Smoothing: tool smoothing parameter allows for the drawing of smooth lines for SpriteRenderer and RawImage components. The smoothing level can be adjusted on a scale from 1 to 10. A value of 1 deactivates smoothing, while a value of 10 provides the maximum line smoothness. When the smoothing value exceeds 1, the line drawing process involves rendering additional brush samples and painting lines may have 2 frames delay. To improve the performance, decrease the Smoothing value to 2-4, or turn it off entirely by setting it to 1:</p> <p> </p> </li> <li> <p>Undo/Redo System: undo/redo system can be disabled to increase performance:</p> <p> </p> </li> </ol>"},{"location":"user-guide/best-practices.html#painting-in-world-space","title":"Painting in World space","text":"<p>Painting in World space uses model normals to avoid painting on back side of the mesh. If your model doesn\u2019t have a Normals, you can generate one in Unity by chossing the <code>Calculate</code> option in the model settings:</p> <p>Alternative, if you don't want to use mesh normals, you can decrease <code>Normal Cutout</code> value in PaintManager component:</p>"},{"location":"user-guide/best-practices.html#drawing-dots-instead-of-lines","title":"Drawing dots instead of lines","text":"<p>To drawing with dots instead of lines, turn off <code>Can Paint Lines</code> in PaintManager component:</p>"},{"location":"user-guide/best-practices.html#disable-brush-rounding","title":"Disable brush rounding","text":"<p>To disable the rounding of the brush, set the <code>Hardness</code> parameter of the brush to 1.</p>"},{"location":"user-guide/best-practices.html#paint-on-sprite-with-transparency","title":"Paint on Sprite with transparency","text":"<p>To paint on Sprite with transparent areas, use Material with Shader <code>XD Paint/Alpha Mask</code> and set Texture as <code>Main Texture</code> and <code>Mask Texture</code>:</p> <p>After, choose the Shader Texture Name as <code>_MainTex</code>:</p>"},{"location":"user-guide/best-practices.html#painting-with-colliders","title":"Painting with colliders","text":"<p>To enable painting using colliders, follow these steps:</p> <ol> <li>Add the <code>ColliderPainter</code> component to a GameObject that has a Rigidbody component. This setup allows painting based on collision events.</li> <li>The ColliderPainter component offers the following key parameters:<ul> <li>Color - defines the color used for painting during collisions.</li> <li>Pressure - adjusts the pressure applied during painting, which affects the brush size.</li> <li>FingerId - specifies the index of the finger used for painting through collisions (useful for multi-touch scenarios).</li> </ul> </li> </ol> <p>This configuration enables painting actions to occur when collisions are detected between objects.</p>"},{"location":"user-guide/best-practices.html#skinnedmeshrenderer-recommendations","title":"SkinnedMeshRenderer recommendations","text":"<p>If you use Skinned Mesh for painting, it is recommended to use default transforms: root animation and mesh objects position as 0:0:0, rotation as 0:0:0, and scale 1:1:1:</p>"},{"location":"user-guide/best-practices.html#pixel-art","title":"Pixel Art","text":"<p>To work with pixel art graphics, set Filter Mode to Point in PaintController and PaintManager components, and set BrushDuplicatePartWidth to 1 in Settings:</p> <p> </p>"},{"location":"user-guide/installation.html","title":"Installation","text":""},{"location":"user-guide/installation.html#requirements","title":"Requirements","text":"<p>To ensure 2D/3D Paint works correctly, please meet the following requirements:</p> <ul> <li>Unity Version: Unity 2019.4 or later.</li> <li>Supported Components: A GameObject with one of the following components\u2014MeshRenderer, SkinnedMeshRenderer, SpriteRenderer, or RawImage\u2014each with an assigned material.</li> <li>UV Map for MeshRenderer/SkinnedMeshRenderer: If you\u2019re using MeshRenderer or SkinnedMeshRenderer, the model must include a UV map.</li> </ul> <p>If your model doesn\u2019t have a UV map, you can generate one in Unity by enabling the <code>Generate Lightmap UVs</code> option in the model settings. This UV map will be stored in the second UV channel. Ensure your shader is compatible with this channel, as most default Unity shaders only support the first UV channel. For optimal results, avoid overlapping areas (no mirroring) in the UV map. Although Unity\u2019s auto-generated UVs can work, creating the UV map in a 3D modeling program usually provides better results.</p>"},{"location":"user-guide/installation.html#install-instructions","title":"Install Instructions","text":"<p>To add 2D/3D Paint to your Unity project, follow these straightforward steps:</p> <pre><code>1.  Create a New Project:\n    - Using Unity 2019.4.0f1 or higher (refer to the release notes for the minimum required Unity version), \n    create a new project;\n    - Select the \u201c3D\u201d or \u201c2D\u201d template, depending on your project\u2019s needs.\n2.  Import 2D/3D Paint via the Package Manager:\n    - Open Unity\u2019s Package Manager;\n    - Navigate to the 2D/3D Paint page;\n    - Click the Download button, then the Import button;\n    - Wait for the \u201cImport Unity Package\u201d popup to appear. Ensure all items are checked (this is the default \n        setting), and then click Import.\n3.  Install Required Packages:\n    - Open Unity\u2019s Package Manager and install the latest version of the following packages:\n    - XR: (Optional) Needed only for VR mode.\n4.  Test the Installation:\n    - Open the Demo scene;\n    - Press Play to start the scene and explore the features;\n    - Enjoy the painting features in your project!\n</code></pre> <p>These steps will get 2D/3D Paint up and running in your Unity project, allowing you to start painting on both 2D and 3D objects right away.</p>"},{"location":"user-guide/layers.html","title":"Working with Layers","text":"<p>2D/3D Paint supports work with layers and blending modes. Each layer represents RenderTexture that can be used for painting. Layers are used to perform tasks such as compositing multiple images. Note that each layer consumes memory. For example, using a 1024x1024 texture will take 4MB (32 bytes per pixel). The blending mode defines how a given layer blends with the layers below it.</p> <p><code>PaintManager</code> component has buttons to handle layers:</p> <p>To add a new layer, click on <code>Add Layer</code> button; To remove the active layer, click on <code>Remove Layer</code> button; To remove the active layer mask, click on <code>Remove Layer Mask</code> button; To merge the active layer with the layer below, click on <code>Merge Layers</code> button; To merge all active layers into the active layer, click on <code>Merge All Layers</code> button; To switch to the active layer, click on <code>Set Next Active</code> button. You can switch to an active layer by clicking on the drag area on the left part of the layer UI; To change the layer's order, drag and drop the left layer area up or down:</p>"},{"location":"user-guide/layers.html#blending-modes","title":"Blending Modes","text":"<p>Asset supports the following blending modes:</p> <ul> <li><code>Normal</code> opaque pixels cover the pixels below them without applying any blending. You can adjust the layer's opacity to reveal the underlying pixels.</li> <li><code>Darken</code> this mode compares the luminance values of each RGB channel in the base and blend colors and keeps the darker one. It doesn\u2019t blend pixels but chooses the darkest color between the two. If the base and blend colors are the same, there is no change.</li> <li><code>Multiply</code> multiplies the luminance of the base color by the blend color, resulting in a darker color. White has no effect, and black pixels remain unchanged.</li> <li><code>ColorBurn</code> darkens the base color more than Multiply by increasing contrast between the base and blend colors, leading to more saturated mid-tones and reduced highlights.</li> <li><code>LinearBurn</code> decreases the brightness of the base color based on the blend color, resulting in a darker effect than Multiply but less saturated than ColorBurn.</li> <li><code>DarkerColor</code> compares the base and blend colors and keeps the darker one without blending the pixels. If both are the same, there is no change.</li> <li><code>Lighten</code> keeps the lighter of the base or blend colors. If the colors are the same, no change occurs.</li> <li><code>Screen</code> results in a brighter color by inverting the base and blend colors, multiplying them, and then inverting the result. Black has no effect, while brighter pixels remain.</li> <li><code>ColorDodge</code> brightens the base color by decreasing the contrast between the base and blend colors, leading to saturated mid-tones and blown highlights.</li> <li><code>LinearDodge</code> increases the brightness of the base color based on the blend color, making the base color lighter. Black has no effect.</li> <li><code>LighterColor</code> compares the base and blend colors and keeps the lighter one without blending the pixels. If both are the same, there is no change.</li> <li><code>Overlay</code> combines Multiply and Screen modes, applying Screen to colors lighter than 50% gray and Multiply to colors darker than 50% gray. 50% gray itself becomes transparent.</li> <li><code>SoftLight</code> applies a subtle darkening or lightening effect based on luminance values.</li> <li><code>HardLight</code> combines Multiply and Screen modes, using the brightness of the blend layer for calculations and keeping the base layer as a reference.</li> <li><code>VividLight</code> darkens colors darker than 50% gray and lightens colors lighter than 50% gray.</li> <li><code>LinearLight</code> uses Linear Dodge on lighter pixels and Linear Burn on darker pixels.</li> <li><code>PinLight</code> combines Darken and Lighten modes, which can result in patches or blotches and removes mid-tones.</li> <li><code>HardMix</code> adds the RGB values of the blend layer to the base layer, resulting in an image with high contrast where only black, white, or the six primary colors are visible.</li> <li><code>Difference</code> calculates the difference between base and blend colors, inverting colors where white is used.</li> <li><code>Exclusion</code> similar to Difference, it inverts base color values with white and produces 50% gray with 50% gray blend. Blending with black has no effect.</li> <li><code>Subtract</code> subtracts pixel values of the blend layer from the base layer, darkening pixels. Black has no effect, and brighter blend values result in darker outcomes.</li> <li><code>Divide</code> opposite of Subtract, brightening pixels by dividing base layer values by blend layer values. White has no effect, and darker blend values result in lighter outcomes.</li> <li><code>Hue</code> keeps the luminosity and saturation of the base pixels while adopting the hue of the blend pixels. Useful for changing hues while maintaining tones and saturation.</li> <li><code>Saturation</code> maintains the luminosity and hue of the base layer while adopting the saturation of the blend layer. A black-and-white blend layer turns the image grayscale due to the lack of saturation.</li> <li><code>Color</code> preserves the luminosity of the base layer while adopting the hue and saturation of the blend layer. Ideal for coloring monochromatic images.</li> <li><code>Luminosity</code> maintains the hue and saturation of the base layer while adopting the luminosity of the blend layer.</li> </ul>"},{"location":"user-guide/layers.html#masks","title":"Masks","text":"<p>Asset supports layers masks. Applying masks to a layer is a reversible way to hide part of a layer. This method allows for more editing flexibility instead of permanently erasing or deleting part of a layer. Mask in asset represents RenderTexture in R8 format and can be created/set from code or by setting the reference to the <code>Mask Texture</code> in <code>LayersContainer</code>.</p> <p> </p>"},{"location":"user-guide/layers.html#layers-container","title":"Layers Container","text":"<p>Layers Data (layers textures and their parameters) can be stored in ScriptableObject which is called LayersContainer. LayersContainer contains all data about layers that <code>PaintManager</code> has: layers textures, names, opacity, blending options, masks data, and layers order. To save layers data to LayersContainer, you can use <code>Save Layers</code> button in <code>PaintManager</code> component:</p> <p>After choosing the path, layers data will be saved to LayersContainer asset, layers textures will be saved to the asset folder automatically. LayersContainer asset has an array of LayerData that contains all layers parameters (right part of the image).</p> <p>If PaintManager has a reference to LayersContainer asset in LayersContainer field, during initialization, it will load layers from the asset:</p> <p>In additional, layers container can be saved/loaded/deleted in runtime from code, see <code>PaintManager</code> paragraph for details</p>"},{"location":"user-guide/quick-start.html","title":"Quick Start Guide","text":"<p>Add a prefab to the scene from path <code>Assets/XDPaint/Prefabs/[XDPaintContainer].prefab</code>. This prefab contains singleton components required for work of the asset.</p>"},{"location":"user-guide/quick-start.html#input-controller","title":"Input Controller","text":"<p>This singleton class handles the management of user input. Let\u2019s look at the parameters of the InputController component:</p> <ul> <li><code>Max Touches Count</code> - maximum number of touches for simultaneous drawing;</li> <li><code>Input Methods</code> - active input methods: VRMode, Pen, Touch, Mouse. By default, all input methods are active;</li> <li><code>Canvases</code> - Canvas list to ignore raycasts (children objects of Canvas will prevent painting);</li> <li><code>Block Raycasts On Press</code> - whether to block painting when user hover the canvas items or not;</li> <li><code>Ignore For Raycasts</code> - GameObjects to ignore raycasts (children objects of Canvas that won't prevent painting);</li> <li><code>Pen Transform</code> - Transform of Pen/Hand for painting, used for VR device;</li> <li><code>Minimal Distance To Paint</code> - minimal distance from Pen to surface to perform painting, used for VR painting.</li> </ul>"},{"location":"user-guide/quick-start.html#raycast-controller","title":"Raycast Controller","text":"<p>This singleton class manages data checks for ray intersections with triangles and stores information about all available objects for performing raycast checks. Let\u2019s look at the parameters of the RaycastController component:</p> <ul> <li><code>Use Depth Texture</code> - whether to use Depth Texture for checking raycasts. This is useful in cases when more than one PaintManager is active on the scene, because in this case, it will paint on the nearest PaintManager to the ray origin. Note that if you use SRP, you need to enable DepthTexture in the URP/HDRP settings.</li> </ul>"},{"location":"user-guide/quick-start.html#paint-controller","title":"Paint Controller","text":"<p>This singleton class stores all PaintManagers. Let\u2019s look at the parameters of the PaintController component:</p> <ul> <li><code>Override Camera</code> - set the camera for the InputController and RaycastController objects, singleton objects. If unchecked, Camera.main will be used;</li> <li><code>Use Shared Settings</code> - whether to use settings of PaintController (Brush, Paint Tool, and Paint Mode) for all PaintManager instances. If flag is disabled each PaintManager uses its own individual settings;</li> <li><code>Paint Mode</code> - the painting mode can be set to either Default or Additive. In Default mode, the drawing results are baked into the Layer Texture each frame. In Additive mode, more precise color and alpha blending is achieved by rendering lines onto the Input Texture, with the results baked into the Layer Texture upon the Mouse Up event;</li> <li><code>Paint Tool</code> - selected tool. Supported tools:<ul> <li><code>Brush</code> - brush tool for painting on the texture;</li> <li><code>Erase</code> - erase tool;</li> <li><code>Bucket</code> - tool for filling texture areas with the selected color;</li> <li><code>Eyedropper</code> - eyedropper tool for picking the color of the brush;</li> <li><code>BrushSampler</code> - tool for sampling brush texture;</li> <li><code>Clone</code> - tool for cloning parts of the texture;</li> <li><code>Blur</code> - tool for blurring parts of the texture;</li> <li><code>GaussianBlur</code> - tool for blurring parts of the texture;</li> <li><code>Grayscale</code> - tool for discolorating parts of the texture.</li> </ul> </li> <li><code>Preset</code> - brush preset saved in <code>Assets/XDPaint/Resources/XDPaintBrushPresets.asset</code>. It stores brushes with different parameters to easily switch between them. See Brush and Presets paragraph for details.</li> </ul> <p>Brush Parameters:</p> <ul> <li><code>Name</code> - name of the brush;</li> <li><code>Source Texture</code> - brush texture. When you add a new brush, make sure that \u00abWrap Mode\u00bb is set as \u00abClamp\u00bb in the settings of the brush texture;</li> <li><code>Filter Mode</code> - FilterMode for brush RenderTexture;</li> <li><code>Color</code> - brush color;</li> <li><code>Size</code> - brush size;</li> <li><code>Hardness</code> - brush hardness. Rounds brush when a value is less than 1;</li> <li><code>Render Angle</code> - brush render angle in degrees;</li> <li><code>Preview</code> - to show a preview of the brush while the user hovers over the object to be painted;</li> </ul>"},{"location":"user-guide/quick-start.html#paint-manager","title":"Paint Manager","text":"<p>This class manages the paint object, serving as the core component for painting on objects. Create the GameObject with the <code>PaintManager</code> component using the Unity menu \u00abGameObject -&gt; 2D/3D Paint\u00bb, or add the <code>PaintManager</code> component to your GameObject. Then select the GameObject to paint in the <code>Object For Painting</code> field. The object to paint must contain one of the supported components: <code>MeshRenderer</code>, <code>SkinnedMeshRenderer</code>, <code>SpriteRenderer</code> or <code>RawImage</code>. If any child of <code>PaintManager</code> GameObject contains an object with one of the supported components, it can automatically assign it to the <code>Object For Painting</code> field by clicking on the <code>Auto Fill</code> button:</p> <p>After clicking on the <code>Auto Fill</code> button, the Object For Painting field will be filled in when one of the supported components is found:</p> <p>If the material or paint object cannot be found automatically, make sure that there is a GameObject with the supported component among the child objects, otherwise, Object For Painting and Material can be assigned manually.</p> <p>Other component settings will appear if Object For Painting and Material have values. Consider the existing settings:</p> <ul> <li><code>Object For Painting</code> - GameObject for painting, must contain one of the supported components;</li> <li><code>Material</code> - the material of the object whose texture field (Shader Texture Name) will be used for drawing;</li> <li><code>Shader Texture Name</code> - the name of the material texture on which it will perform the painting;</li> <li><code>Texture Width</code> - the default texture width is used for objects that do not have the source texture;</li> <li><code>Texture Height</code> - the default texture height is used for objects that do not have the source texture;</li> <li><code>Texture Color</code> - the pixels color of the texture that will be created in case of source texture is not specified;</li> <li><code>Filter Mode</code> - FilterMode for painting RenderTextures;</li> <li><code>UV Channel</code> - the UV channel;</li> <li><code>Paint Space</code> - specifies the coordinate space used for projecting the brush texture onto the surface:<ul> <li><code>UV</code>: Projects the brush texture using the object\u2019s UV coordinates;</li> <li><code>World</code>: Projects brush texture based on world positions for seamless painting across surfaces.</li> </ul> </li> <li><code>Projection Method</code> - determines the method used to project the brush texture onto the surface;</li> <li><code>Projection Direction</code> - determines how the brush normal is calculated for texture projection;</li> <li><code>Normal Cutout</code> - controls the cutoff threshold based on the angle between the surface normal and the viewing direction. By setting a threshold, it helps avoid painting on parts of the model that face away from the painting ray or camera, like the back faces, when working in World Paint Space;</li> <li><code>Max Angle</code> - specifies the maximum angle (in degrees) between the brush normal and the fragment normal for the brush to draw on surface. Adjusting <code>Max Angle</code> allows you to control how much the brush wraps around curved surfaces;</li> <li><code>Angle Attenuation Mode</code> - controls how <code>Max Angle</code> affects the brush\u2019s alpha value;</li> <li><code>Brush Depth Size</code> - controls the depth (thickness) of the brush effect along the brush normal direction, relative to the brush size. Useful for creating effects where the brush should only affect surfaces within a specific depth range;</li> <li><code>Brush Depth Fade Range</code> - defines the range over which the brush effect fades out from full strength to zero along the depth specified by <code>Brush Depth</code>. When greater than 0.0, it creates a smooth transition (fade) from full brush effect to no effect over the specified depth range;</li> <li><code>Edge Softness</code> - controls the softness of the brush edges, affecting how the brush effect attenuates towards the outer radius;</li> <li><code>Paint Mode</code> - mode of painting: default or additive;</li> <li><code>Paint Tool</code> - painting tool, if PaintController has checked Use Shared Settings flag, the tool from PaintController will be used as Paint Tool for all PaintManagers;</li> <li><code>Brush</code> - brush parameters. When selected \u00abCustom\u00bb - PaintManager has unique brush parameters. You can select a ready-to-use preset of the brush from the list. Note that if PaintController has the flag Use Shared Settings, brush parameters will be used from PaintController;</li> <li><code>Copy Source Texture To Layer</code> - copy source texture from material to new layer;</li> <li><code>Use Source Texture as Background Layer</code> - copy source texture from material to background layer;</li> <li><code>Layers Container</code> - a reference to the ScriptableObject of LayersContainer, that contains information about layers, their textures, and parameters. Used for loading previously saved layers.</li> <li><code>Clone Material</code> - button to copy the source material of the object to the new file, can be used only in the Unity Editor;</li> <li><code>Clone Texture</code> - button to copy the source texture of the object to the new file, can be used only in the Unity Editor;</li> <li><code>Undo</code> - button to undo action with the object;</li> <li><code>Redo</code> - button to redo action with the object;</li> <li><code>Bake</code> - button to save the painting results to the source file. Note that texture is stored in RAM and is not written on the disk;</li> <li><code>Save Texture</code> - button to save the texture of the painting results to the file, can only be used in the Unity Editor;</li> <li><code>Save Layers</code> - button to save layers data to ScriptableObject. Let's set up the object to paint on the emission texture:</li> </ul> <p>The texture of shader with the name <code>_EmissionMap</code> is selected. After switching to the game mode, the user will be able to paint on the object <code>LightHouse</code>. The material and the source texture <code>_EmissionMap</code> will be cloned, RenderTexture will be assigned as the new texture. Painting can be done with various input devices, such as a mouse, touch screen, tablet stylus, or VR controller.</p>"},{"location":"user-guide/settings.html","title":"Settings","text":""},{"location":"user-guide/settings.html#main-settings","title":"Main Settings","text":"<p>2D/3D Paint has main settings. The configuration file is located at: <code>Assets/XDPaint/Resources/XDPaintSettings.asset</code>. The settings file is ScriptableObject. Consider the fields in the settings file:</p> <ul> <li><code>Default Brush</code> - default brush texture;</li> <li><code>Default Circle Brush</code> - default brush texture for BrushSampler/Clone tools;</li> <li><code>Default Pattern Texture</code> - default pattern texture for Brush/Bucket tools;</li> <li><code>VR Mode Enabled</code> - whether to use VR input;</li> <li><code>Pressure Enabled</code> - pressure force is applied to the brush size;</li> <li><code>Check Canvas Raycasts</code> - prevent painting on components if any other canvas component lies above the paint object. This also requires setting InputController settings: Canvas and Ignore For Raycasts (optional) fields;</li> <li><code>Raycasts Method</code> - method used to calculate raycasts. Job System method can increase painting performance for mesh components (MeshRenderer and SkinnedMeshRenderer) and requires Burst package that can be installed using Package Manager (Windows -&gt; Package Manager).</li> <li><code>Brush Duplicate Part Width</code> - defines the frequency at which brush samples are rendered in case of using <code>SpriteRenderer</code> and <code>RawImage</code> components. This value affects both the number of vertices and the density of the lines. A higher value results in fewer brush samples being drawn, which can reduce the detail and density of the line. Conversely, a lower value will produce more vertices, leading to dense lines;</li> <li><code>Raycast Interval</code> - defines the frequency at which raycasts will be performed. A higher value results in fewer brush samples being drawn, which can reduce the detail and density of the line. Conversely, a lower value will produce more vertices, leading to dense lines;</li> <li><code>Pixel Per Unit</code> - pixelPerUnit field for sprites. Used for objects that do not have the source sprite;</li> <li><code>Container Game Object Name</code> - the name of the GameObject, for the container object with InputController and RaycastController components.</li> </ul>"},{"location":"user-guide/settings.html#states-settings","title":"States Settings","text":"<p>2D/3D Paint has undo/redo system and its setting which is called \u00abStates Settings\u00bb. The configuration file is located at: Assets/XDPaint/Resources/XDPaintStatesSettings.asset. The settings file is ScriptableObject. Consider the fields in the settings file:</p> <ul> <li><code>Undo Redo Enabled</code> - undo and redo functionality is enabled. If the application doesn't have undo/redo functionality, it is recommended to turn this flag off to reduce memory usage;</li> <li><code>Enable Undo Redo For Properties And Actions</code> - save undo/redo actions to change layer parameters such as opacity, blending mode, name, layer index, etc. If this flag is disabled, only layers RenderTextures will be saved on actions performed;</li> <li><code>Undo Redo Max Actions Count</code> - the maximum amount of actions that store undo/redo.</li> </ul>"},{"location":"user-guide/tools-and-brushes.html","title":"Tools & Brushes","text":""},{"location":"user-guide/tools-and-brushes.html#tools","title":"Tools","text":"<p>Tool - is an instrument for processing layer texture when the user paints on it. The asset has 9 built-in tools: brush, erase, bucket, eyedropper, brush sampler, clone, blur, gaussian blur, and grayscale tool. User can switch between tools to get different drawing results. Let\u2019s look at tools functional:</p> <ul> <li> <p>Brush - default tool for painting. Tool parameters:</p> <ul> <li><code>Can Paint Lines</code> - whether to paint lines. If this flag is disabled, only dots will be used for painting;</li> <li><code>Draw On Brush Move Only</code> - render brush only when a user moves the input source (mouse, finger, pen, etc.).</li> <li><code>Smoothing</code> - smoothing parameter allows for the drawing of smooth lines for SpriteRenderer and RawImage components. The smoothing level can be adjusted on a scale from 1 to 10. A value of 1 deactivates smoothing, while a value of 10 provides the maximum line smoothness. When the smoothing value exceeds 1, the line drawing process involves rendering additional brush samples and painting lines may have 2 frames delay:</li> </ul> <p> In this example, to demonstrate the differences between smoothing values, drawing is done at a target FPS value of 20 </p> <ul> <li><code>Randomize Points Quads Angle</code> - randomizes each brush samples angle while drawing points;</li> <li><code>Randomize Lines Quads Angle</code> - randomizes each brush samples angle while drawing lines;</li> </ul> <p>Note</p> <p>Drawing with pattern textures is supported only in Additive PaintMode</p> <ul> <li><code>Use Pattern</code> - whether to draw using pattern texture instead of solid color.</li> <li><code>Pattern Texture</code> - reference to the pattern texture;</li> <li><code>Pattern Scale</code> - scale of pattern texture;</li> <li><code>Pattern Angle</code> - angle of drawing pattern texture;</li> <li><code>Pattern Offset</code> - offset of pattern texture drawing;</li> </ul> </li> <li> <p>Erase - erase layer texture using the brush, opposite for drawing;  </p> <p>Note</p> <p>Bucket tool works in UV space</p> </li> <li> <p>Bucket - tool for filling parts of the texture with selected color. Tool parameters:  </p> <ul> <li><code>Tolerance</code> - tolerance value from 0 to 1. Tolerance means how many pixels it will cover. A bigger value means that more pixels will be filled with brush color.</li> <li><code>Can Fill Alpha</code> - whether to fill transparent pixels of the layer;</li> <li><code>Use Pattern</code> - whether to fill using pattern texture instead of solid color;</li> <li><code>Pattern Texture</code> - reference to the pattern texture;</li> <li><code>Pattern Scale</code> - scale of pattern texture;</li> <li><code>Pattern Angle</code> - angle of drawing pattern texture;</li> <li><code>Pattern Offset</code> - offset of pattern texture drawing;</li> </ul> </li> <li> <p>Eyedropper - pick a color and set it as a brush color. Tool parameters:</p> <ul> <li><code>Use All Active Layers</code> - use all layers for color picking. If disabled, only an active layer will be used;</li> <li><code>Sample Alpha</code> - whether to sample pixels alpha.</li> </ul> <p>Note</p> <p>BrushSampler tool works in UV space</p> </li> <li> <p>BrushSampler - copies a part of the drawing area to a brush texture.</p> </li> <li> <p>Clone - tool for cloning parts of the texture. Clone tool works the same way as Photoshop or any other painting software. The first click on the object will take the starting position of cloning, all follow-up clicks will clone parts of texture. Tool parameters:</p> <p>Note</p> <p>Clone tool works in UV space</p> <ul> <li><code>Copy Texture On Press Down</code> - whether to copy source texture on press down;</li> <li><code>Use All Active Layers</code> - use all active layers for cloning. If disabled only active layer will be used.</li> </ul> </li> <li> <p>Blur - tool for blurring parts of the texture. Blur implementation using a simplified Gaussian blur algorithm that works in two Shader Passes and can be configured to change blur strength. Blur tool has such parameters:</p> <ul> <li><code>Iterations</code> - iterations count for blurring. A higher value means strengthening the blur. It is recommended to use parameters in a range of 1 to 5. A higher value also means that the blur will use more GPU resources and the draw call count will be increased (two draw calls per iteration);</li> <li><code>BlurStrength</code> - the strength of the blur. Zero means minimal blur, higher value - strengthen blur;</li> <li><code>DownscaleRatio</code> - value for the number of times to downscale the texture size for blurring;</li> <li><code>Use All Active Layers</code> - use all active layers for blurring. If disabled only the active layer will be used.</li> </ul> </li> <li> <p>Gaussian Blur - tool for blurring parts of the texture. Blur implementation using Gaussian blur algorithm works in one Shader Pass and can be configured to change blur strength. Blur tool has such parameters:</p> <ul> <li><code>Kernel size</code> - iterations count for blurring, a higher value means strengthening the blur. Recommended to use parameters ranging from 3 to 7;</li> <li><code>Spread</code> - the spread of blur. Zero means minimal blur, higher value - strengthen blur. Recommended to use parameters in the range from 0 to 5;</li> <li><code>Use All Active Layers</code> - use all active layers for blurring. If disabled only the active layer will be used.</li> </ul> </li> <li> <p>Grayscale - tool for layer texture discoloration. The area above the brush discolors when a user draws with the grayscale tool (saturation set to 0).</p> </li> </ul>"},{"location":"user-guide/tools-and-brushes.html#brushes","title":"Brushes","text":"<p>The asset has a preset system that stores brush parameters in ScriptableObject, which allows them to be reused with <code>PaintManagers</code>/<code>PaintController</code>. Presets located in the file at: <code>Assets/XDPaint/Resources/XDPaintBrushPresets.asset</code>. You can save brush parameters by name and apply them to other objects from the list. If you change the non-custom parameters of brush in <code>PaintManager</code>/<code>PaintController</code> inspector window, data won\u2019t be written to Presets automatically.  </p> <p>Asset have built-in presets that can be reused or modified. Presets can be re-saved using PaintController/PaintManager Inspector window or changed by selecting <code>XDPaintBrushPresets</code> asset in Project window and editing in Inspector window.</p> <p> </p> <p>Preset can be re-saved to a new preset, for this click on <code>Save As</code> button. Preset can be renamed, for this click on <code>Rename</code> button and choose a new name and click on <code>Save</code> button. Preset can be removed, for this click on <code>Remove</code> button and confirm it using the dialogue box. You can use one brush parameters for all PaintManagers, for that check <code>Use Shared Settings</code> in <code>PaintController</code>, otherwise, each <code>PaintManager</code> will have unique brush parameters.</p>"},{"location":"user-guide/tools-and-brushes.html#adding-new-brush","title":"Adding New Brush","text":"<p>To add a new brush, select <code>[XDPaintContainer]</code> GameObject in Hierarchy tab, then in Inspector tab set a unique brush name, select brush texture, and brush parameters, and save it as preset using <code>Save As</code> button. It also works the same way in <code>PaintManager</code> component. A new brush will be added to Brush Presets (<code>XDPaintBrushPresets.asset</code>) and can be chosen in <code>PaintController</code>/<code>PaintManager</code> components.</p>"},{"location":"user-guide/vr-support.html","title":"VR Support","text":"<p>2D/3D Paint supports work with VR. Asset uses Unity XR System and support for any other VR plugins can be easily implemented and require minimal code changes to properly work with VR input devices. To enable VR support, perform the following steps:</p> <p>Alternatively, you can uncomment the first line of InputController <code>#define XDPAINT_VR_ENABLE</code>.</p> <ul> <li>(Optional) Configure VR input devices in <code>InputController.InitVR()</code> method, current body of the method can be replaced;</li> <li>(Optional) Replace XR input line in InputController to change VR input trigger for painting, as an example:</li> </ul> <p>Next line can be changed for VR device input</p> <pre><code>if (leftHandedControllers.Count &gt; 0 &amp;&amp; leftHandedControllers[0].TryGetFeatureValue(CommonUsages.triggerButton, out var triggerValue) &amp;&amp; triggerValue)\n</code></pre> <p>Replace it with:</p> <p>Next line can be changed for VR device input</p> <pre><code>if (leftHandedControllers.Count &gt; 0 &amp;&amp; leftHandedControllers[0].TryGetFeatureValue(CommonUsages.primaryButton, out var triggerValue) &amp;&amp; triggerValue)\n</code></pre> <p>Set <code>Pen Transform</code> as your pen in the InputController component. That\u2019s all! Your VR device is ready to paint!</p>"}]}